@@ -29,7 +29,7 @@ void sha256_init(SHA256_CTX *ctxt);
 void sha256_update(SHA256_CTX *ctxt, const void *data, size_t data_len);
 SHA256_DIGEST sha256_finish(SHA256_CTX *ctxt);
 
-void md5_init(MD5_CTX *ctxt);
+void md5_init(MD5_CTX *ctxt); // NOLINT(readability-redundant-declaration, readability-inconsistent-declaration-parameter-name)
 void md5_update(MD5_CTX *ctxt, const void *data, size_t data_len);
 MD5_DIGEST md5_finish(MD5_CTX *ctxt);
 
