@@ -112,7 +112,7 @@ private:
  * RAII-style wrapper for owning a `CLock`.
  *
  * @ingroup Locks
- * 
+ *
  * @remark This wrapper is only necessary because the clang thread-safety attributes
  * are not available for `std::lock_guard` except when explicitly using libc++.
  */
@@ -130,6 +130,8 @@ public:
 		m_Lock.unlock();
 	}
 
+	CLockScope(const CLockScope &) = delete;
+
 private:
 	CLock &m_Lock;
 };
