@@ -72,13 +72,25 @@
 		} \
 	} while(false)
 
+/**
+ * Breaks into the debugger with a message.
+ *
+ * @ingroup Debug
+ * @param fmt A printf styled format message that should be printed in case the
+ * code is reached.
+ *
+ * @remark Also works in release mode.
+ *
+ * @see dbg_break
+ */
+#define dbg_assert_failed(fmt, ...) dbg_assert_imp(__FILE__, __LINE__, fmt, ##__VA_ARGS__)
+
 /**
  * Use dbg_assert instead!
  *
  * @ingroup Debug
  */
-[[gnu::format(printf, 3, 4)]]
-[[noreturn]] void
+[[gnu::format(printf, 3, 4)]] [[noreturn]] void
 dbg_assert_imp(const char *filename, int line, const char *fmt, ...);
 
 /**
@@ -1202,17 +1214,6 @@ void net_unix_set_addr(UNIXSOCKETADDR *addr, const char *path);
  */
 void net_unix_close(UNIXSOCKET sock);
 
-#elif defined(CONF_FAMILY_WINDOWS)
-
-/**
- * Formats a Windows error code as a human-readable string.
- *
- * @param error The Windows error code.
- *
- * @return A new std::string representing the error code.
- */
-std::string windows_format_system_message(unsigned long error);
-
 #endif
 
 /**
@@ -1268,7 +1269,7 @@ int str_format_opt(char *buffer, int buffer_size, const char *format, Args... ar
 }
 
 template<>
-inline int str_format_opt(char *buffer, int buffer_size, const char *format, int val)
+inline int str_format_opt(char *buffer, int buffer_size, const char *format, int val) // NOLINT(readability-inconsistent-declaration-parameter-name)
 {
 	if(strcmp(format, "%d") == 0)
 	{
@@ -1678,154 +1679,6 @@ int str_utf8_comp_confusable(const char *str1, const char *str2);
  */
 int str_utf8_tolower_codepoint(int code);
 
-/**
- * Compares two UTF-8 strings case insensitively.
- *
- * @ingroup Strings
- *
- * @param a String to compare.
- * @param b String to compare.
- *
- * @return `< 0` if string a is less than string b.
- * @return `0` if string a is equal to string b.
- * @return `> 0` if string a is greater than string b.
- */
-int str_utf8_comp_nocase(const char *a, const char *b);
-
-/**
- * Compares up to `num` bytes of two UTF-8 strings case insensitively.
- *
- * @ingroup Strings
- *
- * @param a String to compare.
- * @param b String to compare.
- * @param num Maximum bytes to compare.
- *
- * @return `< 0` if string a is less than string b.
- * @return `0` if string a is equal to string b.
- * @return `> 0` if string a is greater than string b.
- */
-int str_utf8_comp_nocase_num(const char *a, const char *b, int num);
-
-/**
- * Finds a UTF-8 string inside another UTF-8 string case insensitively.
- *
- * @ingroup Strings
- *
- * @param haystack String to search in.
- * @param needle String to search for.
- * @param end A pointer that will be set to a pointer into haystack directly behind the
- *            last character where the needle was found. Will be set to `nullptr `if needle
- *            could not be found. Optional parameter.
- *
- * @return A pointer into haystack where the needle was found.
- * @return Returns `nullptr` if needle could not be found.
- *
- * @remark The strings are treated as null-terminated strings.
- */
-const char *str_utf8_find_nocase(const char *haystack, const char *needle, const char **end = nullptr);
-
-/**
- * Skips leading characters that render as spaces.
- *
- * @ingroup Strings
- *
- * @param str Input string.
- *
- * @return Pointer to the first non-whitespace character found within the string.
- * @remark The strings are treated as null-terminated strings.
- */
-const char *str_utf8_skip_whitespaces(const char *str);
-
-/**
- * Moves a cursor forwards in an UTF-8 string.
- *
- * @ingroup Strings
- *
- * @param str UTF-8 string.
- * @param cursor Position in the string.
- *
- * @return New cursor position.
- *
- * @remark Won't move the cursor beyond the null-termination marker.
- * @remark The strings are treated as null-terminated.
- */
-int str_utf8_forward(const char *str, int cursor);
-
-/**
- * Checks if a strings contains just valid UTF-8 characters.
- *
- * @ingroup Strings
- *
- * @param str Pointer to a possible UTF-8 string.
- *
- * @return `0` if invalid characters were found, `1` if only valid characters were found.
- *
- * @remark The string is treated as null-terminated UTF-8 string.
- */
-int str_utf8_check(const char *str);
-
-/**
- * Copies a number of UTF-8 characters from one string to another.
- *
- * @ingroup Strings
- *
- * @param dst Pointer to a buffer that shall receive the string.
- * @param src String to be copied.
- * @param dst_size Size of the buffer dst.
- * @param num Maximum number of UTF-8 characters to be copied.
- *
- * @remark The strings are treated as null-terminated strings.
- * @remark Garantees that dst string will contain null-termination.
- */
-void str_utf8_copy_num(char *dst, const char *src, int dst_size, int num);
-
-/**
- * Determines the byte size and UTF-8 character count of a UTF-8 string.
- *
- * @ingroup Strings
- *
- * @param str Pointer to the string.
- * @param max_size Maximum number of bytes to count.
- * @param max_count Maximum number of UTF-8 characters to count.
- * @param size Pointer to store size (number of non. Zero bytes) of the string.
- * @param count Pointer to store count of UTF-8 characters of the string.
- *
- * @remark The string is treated as null-terminated UTF-8 string.
- * @remark It's the user's responsibility to make sure the bounds are aligned.
- */
-void str_utf8_stats(const char *str, size_t max_size, size_t max_count, size_t *size, size_t *count);
-
-/**
- * Converts a byte offset of a UTF-8 string to the UTF-8 character offset.
- *
- * @ingroup Strings
- *
- * @param str Pointer to the string.
- * @param byte_offset Offset in bytes.
- *
- * @return Offset in UTF-8 characters. Clamped to the maximum length of the string in UTF-8 characters.
- *
- * @remark The string is treated as a null-terminated UTF-8 string.
- * @remark It's the user's responsibility to make sure the bounds are aligned.
- */
-size_t str_utf8_offset_bytes_to_chars(const char *str, size_t byte_offset);
-
-/**
- * Converts a UTF-8 character offset of a UTF-8 string to the byte offset.
- *
- * @ingroup Strings
- *
- * @param str Pointer to the string.
- * @param char_offset Offset in UTF-8 characters.
- *
- * @return Offset in bytes. Clamped to the maximum length of the string in bytes.
- *
- * @remark The string is treated as a null-terminated UTF-8 string.
- * @remark It's the user's responsibility to make sure the bounds are aligned.
- */
-size_t str_utf8_offset_chars_to_bytes(const char *str, size_t char_offset);
-
 /**
  * Packs 4 big endian bytes into an unsigned.
  *
@@ -1912,20 +1765,6 @@ enum class EShellExecuteWindowState
 	BACKGROUND,
 };
 
-#if defined(CONF_FAMILY_WINDOWS)
-/**
- * Converts an array of arguments into a wide string with proper escaping for Windows command-line usage.
- *
- * @ingroup Shell
- *
- * @param arguments Array of arguments.
- * @param num_arguments The number of arguments.
- *
- * @return Wide string of arguments with escaped quotes.
- */
-std::wstring windows_args_to_wide(const char **arguments, const size_t num_arguments);
-#endif
-
 /**
  * Executes a given file.
  *
@@ -2130,141 +1969,7 @@ public:
 	{
 		cmdline_free(m_Argc, m_ppArgv);
 	}
+	CCmdlineFix(const CCmdlineFix &) = delete;
 };
 
-#if defined(CONF_FAMILY_WINDOWS)
-/**
- * Converts a UTF-8 encoded string to a wide character string
- * for use with the Windows API.
- *
- * @ingroup Shell
- *
- * @param str The UTF-8 encoded string to convert.
- *
- * @return The argument as a wide character string.
- *
- * @remark The strings are treated as null-terminated strings.
- * @remark Fails with assertion error if passed UTF-8 is invalid.
- */
-std::wstring windows_utf8_to_wide(const char *str);
-
-/**
- * Converts a wide character string obtained from the Windows API
- * to a UTF-8 encoded string.
- *
- * @ingroup Shell
- *
- * @param wide_str The wide character string to convert.
- *
- * @return The argument as a UTF-8 encoded string, wrapped in an optional.
- * The optional is empty, if the wide string contains invalid codepoints.
- *
- * @remark The strings are treated as null-terminated strings.
- */
-std::optional<std::string> windows_wide_to_utf8(const wchar_t *wide_str);
-
-/**
- * This is a RAII wrapper to initialize/uninitialize the Windows COM library,
- * which may be necessary for using the @link open_file @endlink and
- * @link open_link @endlink functions.
- * Must be used on every thread. It's automatically used on threads created
- * with @link thread_init @endlink. Pass `true` to the constructor on threads
- * that own a window (i.e. pump a message queue).
- *
- * @ingroup Shell
- */
-class CWindowsComLifecycle
-{
-public:
-	CWindowsComLifecycle(bool HasWindow);
-	~CWindowsComLifecycle();
-};
-
-/**
- * Registers a protocol handler.
- *
- * @ingroup Shell
- *
- * @param protocol_name The name of the protocol.
- * @param executable The absolute path of the executable that will be associated with the protocol.
- * @param updated Pointer to a variable that will be set to `true`, iff the shell needs to be updated.
- *
- * @return `true` on success, `false` on failure.
- *
- * @remark The caller must later call @link shell_update @endlink, iff the shell needs to be updated.
- */
-bool shell_register_protocol(const char *protocol_name, const char *executable, bool *updated);
-
-/**
- * Registers a file extension.
- *
- * @ingroup Shell
- *
- * @param extension The file extension, including the leading dot.
- * @param description A readable description for the file extension.
- * @param executable_name A unique name that will used to describe the application.
- * @param executable The absolute path of the executable that will be associated with the file extension.
- * @param updated Pointer to a variable that will be set to `true`, iff the shell needs to be updated.
- *
- * @return `true` on success, `false` on failure.
- *
- * @remark The caller must later call @link shell_update @endlink, iff the shell needs to be updated.
- */
-bool shell_register_extension(const char *extension, const char *description, const char *executable_name, const char *executable, bool *updated);
-
-/**
- * Registers an application.
- *
- * @ingroup Shell
- *
- * @param name Readable name of the application.
- * @param executable The absolute path of the executable being registered.
- * @param updated Pointer to a variable that will be set to `true`, iff the shell needs to be updated.
- *
- * @return `true` on success, `false` on failure.
- *
- * @remark The caller must later call @link shell_update @endlink, iff the shell needs to be updated.
- */
-bool shell_register_application(const char *name, const char *executable, bool *updated);
-
-/**
- * Unregisters a protocol or file extension handler.
- *
- * @ingroup Shell
- *
- * @param shell_class The shell class to delete.
- * For protocols this is the name of the protocol.
- * For file extensions this is the program ID associated with the file extension.
- * @param updated Pointer to a variable that will be set to `true`, iff the shell needs to be updated.
- *
- * @return `true` on success, `false` on failure.
- *
- * @remark The caller must later call @link shell_update @endlink, iff the shell needs to be updated.
- */
-bool shell_unregister_class(const char *shell_class, bool *updated);
-
-/**
- * Unregisters an application.
- *
- * @ingroup Shell
- *
- * @param executable The absolute path of the executable being unregistered.
- * @param updated Pointer to a variable that will be set to `true`, iff the shell needs to be updated.
- *
- * @return `true` on success, `false` on failure.
- *
- * @remark The caller must later call @link shell_update @endlink, iff the shell needs to be updated.
- */
-bool shell_unregister_application(const char *executable, bool *updated);
-
-/**
- * Notifies the system that a protocol or file extension has been changed and the shell needs to be updated.
- *
- * @ingroup Shell
- *
- * @remark This is a potentially expensive operation, so it should only be called when necessary.
- */
-void shell_update();
-#endif
-
 #endif
