@@ -42,8 +42,8 @@ typedef int (*FS_LISTDIR_CALLBACK_FILEINFO)(const CFsFileInfo *info, int is_dir,
 typedef struct NETSOCKET_INTERNAL *NETSOCKET;
 
 /**
-* The maximum bytes necessary to encode one Unicode codepoint with UTF-8.
-*/
+ * The maximum bytes necessary to encode one Unicode codepoint with UTF-8.
+ */
 inline constexpr auto UTF8_BYTE_LENGTH = 4;
 
 inline constexpr auto IO_MAX_PATH_LENGTH = 512;
@@ -57,9 +57,9 @@ inline constexpr auto NETTYPE_WEBSOCKET_IPV4 = 1 << 2;
 inline constexpr auto NETTYPE_WEBSOCKET_IPV6 = 1 << 3;
 inline constexpr auto NETTYPE_LINK_BROADCAST = 1 << 4;
 /**
-* 0.7 address. This is a flag in NETADDR to avoid introducing a parameter to every networking function
-* to differenciate between 0.6 and 0.7 connections.
-*/
+ * 0.7 address. This is a flag in NETADDR to avoid introducing a parameter to every networking function
+ * to differentiate between 0.6 and 0.7 connections.
+ */
 inline constexpr auto NETTYPE_TW7 = 1 << 5;
 
 inline constexpr auto NETTYPE_ALL = NETTYPE_IPV4 | NETTYPE_IPV6 | NETTYPE_WEBSOCKET_IPV4 | NETTYPE_WEBSOCKET_IPV6;
@@ -108,7 +108,7 @@ typedef void *PROCESS;
  *
  * @ingroup Shell
  */
-constexpr PROCESS INVALID_PROCESS = nullptr;
+constexpr PROCESS INVALID_PROCESS = nullptr; // NOLINT(misc-misplaced-const)
 #else
 /**
  * A handle for a process.
