@@ -188,7 +188,7 @@ void CGraphicsBackend_Threaded::ProcessError(const SGfxErrorContainer &Error)
 		else
 			VerboseStr.append(ErrStr.m_Err);
 	}
-	dbg_assert(false, "%s", VerboseStr.c_str());
+	dbg_assert_failed("%s", VerboseStr.c_str());
 }
 
 bool CGraphicsBackend_Threaded::GetWarning(std::vector<std::string> &WarningStrings)
@@ -358,8 +358,7 @@ void CCommandProcessor_SDL_GL::HandleWarning()
 		return;
 	}
 	default:
-		dbg_assert(false, "Unhandled graphics warning type %d", (int)m_Warning.m_WarningType);
-		dbg_break();
+		dbg_assert_failed("Unhandled graphics warning type %d", (int)m_Warning.m_WarningType);
 	}
 }
 
@@ -393,8 +392,7 @@ void CCommandProcessor_SDL_GL::RunBuffer(CCommandBuffer *pBuffer)
 		if(m_General.RunCommand(pCommand))
 			continue;
 
-		dbg_assert(false, "Unknown graphics command %d", pCommand->m_Cmd);
-		dbg_break();
+		dbg_assert_failed("Unknown graphics command %d", pCommand->m_Cmd);
 	}
 
 	m_pGLBackend->EndCommands();
@@ -640,7 +638,7 @@ static bool BackendInitGlew(EBackendType BackendType, int &GlewMajor, int &GlewM
 	}
 	else
 	{
-		dbg_assert(false, "Invalid backend type for glew: %d", (int)BackendType);
+		dbg_assert_failed("Invalid backend type for glew: %d", (int)BackendType);
 	}
 
 	return false;
@@ -839,9 +837,9 @@ static Uint32 MessageBoxTypeToSdlFlags(IGraphics::EMessageBoxType Type)
 		return SDL_MESSAGEBOX_WARNING;
 	case IGraphics::EMessageBoxType::INFO:
 		return SDL_MESSAGEBOX_INFORMATION;
+	default:
+		dbg_assert_failed("Type invalid");
 	}
-	dbg_assert(false, "Type invalid");
-	return 0;
 }
 
 static std::optional<int> ShowMessageBoxImpl(const IGraphics::CMessageBox &MessageBox, SDL_Window *pWindow)
@@ -1018,8 +1016,8 @@ void CGraphicsBackend_SDL_GL::GetVideoModes(CVideoMode *pModes, int MaxModes, in
 
 	// Only collect fullscreen modes when requested, that makes sure in windowed mode no refresh rates are shown that aren't supported without
 	// fullscreen anyway(except fullscreen desktop)
-	bool IsFullscreenDestkop = m_pWindow != nullptr && (((SDL_GetWindowFlags(m_pWindow) & SDL_WINDOW_FULLSCREEN_DESKTOP) == SDL_WINDOW_FULLSCREEN_DESKTOP) || g_Config.m_GfxFullscreen == 3);
-	bool CollectFullscreenModes = m_pWindow == nullptr || ((SDL_GetWindowFlags(m_pWindow) & SDL_WINDOW_FULLSCREEN) != 0 && !IsFullscreenDestkop);
+	bool IsFullscreenDesktop = m_pWindow != nullptr && (((SDL_GetWindowFlags(m_pWindow) & SDL_WINDOW_FULLSCREEN_DESKTOP) == SDL_WINDOW_FULLSCREEN_DESKTOP) || g_Config.m_GfxFullscreen == 3);
+	bool CollectFullscreenModes = m_pWindow == nullptr || ((SDL_GetWindowFlags(m_pWindow) & SDL_WINDOW_FULLSCREEN) != 0 && !IsFullscreenDesktop);
 
 	if(SDL_GetDesktopDisplayMode(ScreenId, &DesktopMode) < 0)
 	{
@@ -1048,7 +1046,7 @@ void CGraphicsBackend_SDL_GL::GetVideoModes(CVideoMode *pModes, int MaxModes, in
 		{
 			// if last mode was equal, ignore this one --- in fullscreen this can really only happen if the screen
 			// supports different color modes
-			// in non fullscren these are the modes that show different refresh rate, but are basically the same
+			// in non fullscreen these are the modes that show different refresh rate, but are basically the same
 			if(NumModesInserted > 0 && pModes[NumModesInserted - 1].m_WindowWidth == Mode.w && pModes[NumModesInserted - 1].m_WindowHeight == Mode.h && (pModes[NumModesInserted - 1].m_RefreshRate == Mode.refresh_rate || (Mode.refresh_rate != DesktopMode.refresh_rate && !CollectFullscreenModes)))
 				return;
 
@@ -1066,7 +1064,7 @@ void CGraphicsBackend_SDL_GL::GetVideoModes(CVideoMode *pModes, int MaxModes, in
 
 		ModeInsert(Mode);
 
-		if(IsFullscreenDestkop)
+		if(IsFullscreenDesktop)
 			break;
 
 		if(NumModesInserted >= MaxModes)
@@ -1125,6 +1123,11 @@ int CGraphicsBackend_SDL_GL::Init(const char *pName, int *pScreen, int *pWidth,
 	int GlewMajor = 0;
 	int GlewMinor = 0;
 	int GlewPatch = 0;
+	*pScreen = 0;
+	*pWidth = *pDesktopWidth = *pCurrentWidth = 800;
+	*pHeight = *pDesktopHeight = *pCurrentHeight = 600;
+	*pRefreshRate = 60;
+	*pFsaaSamples = 0;
 	log_info("gfx", "Created headless context");
 #else
 	// print sdl version
@@ -1196,8 +1199,7 @@ int CGraphicsBackend_SDL_GL::Init(const char *pName, int *pScreen, int *pWidth,
 		pBackendName = "Vulkan";
 		break;
 	default:
-		dbg_assert(false, "Invalid m_BackendType: %d", m_BackendType);
-		dbg_break();
+		dbg_assert_failed("Invalid m_BackendType: %d", m_BackendType);
 	}
 	log_info("gfx", "Created %s %d.%d context", pBackendName, g_Config.m_GfxGLMajor, g_Config.m_GfxGLMinor);
 
@@ -1445,7 +1447,7 @@ int CGraphicsBackend_SDL_GL::Init(const char *pName, int *pScreen, int *pWidth,
 		CmdGL.m_pGpuList = &m_GpuList;
 		CmdGL.m_pReadPresentedImageDataFunc = &m_ReadPresentedImageDataFunc;
 		CmdGL.m_pStorage = pStorage;
-		CmdGL.m_pCapabilities = &m_Capabilites;
+		CmdGL.m_pCapabilities = &m_Capabilities;
 		CmdGL.m_pInitError = &InitError;
 		CmdGL.m_RequestedMajor = g_Config.m_GfxGLMajor;
 		CmdGL.m_RequestedMinor = g_Config.m_GfxGLMinor;
@@ -1501,9 +1503,9 @@ int CGraphicsBackend_SDL_GL::Init(const char *pName, int *pScreen, int *pWidth,
 		// try setting to version string's supported version
 		if(InitError == -2)
 		{
-			g_Config.m_GfxGLMajor = m_Capabilites.m_ContextMajor;
-			g_Config.m_GfxGLMinor = m_Capabilites.m_ContextMinor;
-			g_Config.m_GfxGLPatch = m_Capabilites.m_ContextPatch;
+			g_Config.m_GfxGLMajor = m_Capabilities.m_ContextMajor;
+			g_Config.m_GfxGLMinor = m_Capabilities.m_ContextMinor;
+			g_Config.m_GfxGLPatch = m_Capabilities.m_ContextPatch;
 		}
 
 		if(pErrorStr != nullptr)
@@ -1598,18 +1600,15 @@ void CGraphicsBackend_SDL_GL::Minimize()
 	SDL_MinimizeWindow(m_pWindow);
 }
 
-void CGraphicsBackend_SDL_GL::Maximize()
-{
-	// TODO: SDL
-}
-
 void CGraphicsBackend_SDL_GL::SetWindowParams(int FullscreenMode, bool IsBorderless)
 {
+	// The flags have to be kept consistent with flags set in the CGraphics_Threaded::IssueInit function!
+
 	if(FullscreenMode > 0)
 	{
 		bool IsDesktopFullscreen = FullscreenMode == 2;
 #ifndef CONF_FAMILY_WINDOWS
-		//  special mode for windows only
+		//  Windowed fullscreen is only available on Windows, use desktop fullscreen on other platforms
 		IsDesktopFullscreen |= FullscreenMode == 3;
 #endif
 		if(FullscreenMode == 1)
@@ -1627,7 +1626,7 @@ void CGraphicsBackend_SDL_GL::SetWindowParams(int FullscreenMode, bool IsBorderl
 			SDL_SetWindowFullscreen(m_pWindow, SDL_WINDOW_FULLSCREEN_DESKTOP);
 			SDL_SetWindowResizable(m_pWindow, SDL_FALSE);
 		}
-		else
+		else // Windowed fullscreen
 		{
 			SDL_SetWindowFullscreen(m_pWindow, 0);
 			SDL_SetWindowBordered(m_pWindow, SDL_TRUE);
@@ -1644,7 +1643,7 @@ void CGraphicsBackend_SDL_GL::SetWindowParams(int FullscreenMode, bool IsBorderl
 			}
 		}
 	}
-	else
+	else // Windowed
 	{
 		SDL_SetWindowFullscreen(m_pWindow, 0);
 		SDL_SetWindowBordered(m_pWindow, SDL_bool(!IsBorderless));
@@ -1652,24 +1651,33 @@ void CGraphicsBackend_SDL_GL::SetWindowParams(int FullscreenMode, bool IsBorderl
 	}
 }
 
-bool CGraphicsBackend_SDL_GL::SetWindowScreen(int Index)
+bool CGraphicsBackend_SDL_GL::SetWindowScreen(int Index, bool MoveToCenter)
 {
 	if(Index < 0 || Index >= m_NumScreens)
 	{
+		log_error("gfx", "Invalid screen number: %d (min: 0, max: %d)", Index, m_NumScreens);
 		return false;
 	}
 
 	SDL_Rect ScreenPos;
 	if(SDL_GetDisplayBounds(Index, &ScreenPos) != 0)
 	{
+		log_error("gfx", "Unable to get bounds of screen %d: %s", Index, SDL_GetError());
 		return false;
 	}
-	// Todo SDL: remove this when fixed (changing screen when in fullscreen is bugged)
-	SDL_SetWindowBordered(m_pWindow, SDL_TRUE); //fixing primary monitor goes black when switch screen (borderless OpenGL)
 
-	SDL_SetWindowPosition(m_pWindow,
-		SDL_WINDOWPOS_CENTERED_DISPLAY(Index),
-		SDL_WINDOWPOS_CENTERED_DISPLAY(Index));
+	if(MoveToCenter)
+	{
+		SDL_SetWindowPosition(m_pWindow,
+			SDL_WINDOWPOS_CENTERED_DISPLAY(Index),
+			SDL_WINDOWPOS_CENTERED_DISPLAY(Index));
+	}
+	else
+	{
+		SDL_SetWindowPosition(m_pWindow,
+			SDL_WINDOWPOS_UNDEFINED_DISPLAY(Index),
+			SDL_WINDOWPOS_UNDEFINED_DISPLAY(Index));
+	}
 
 	return UpdateDisplayMode(Index);
 }
