@@ -57,7 +57,7 @@ static CVideoMode g_aFakeModes[] = {
 void CGraphics_Threaded::FlushVertices(bool KeepVertices)
 {
 	CCommandBuffer::SCommand_Render Cmd;
-	int PrimType;
+	EPrimitiveType PrimType;
 	size_t PrimCount, NumVerts;
 	FlushVerticesImpl(KeepVertices, PrimType, PrimCount, NumVerts, Cmd, sizeof(CCommandBuffer::SVertex));
 
@@ -70,7 +70,7 @@ void CGraphics_Threaded::FlushVertices(bool KeepVertices)
 void CGraphics_Threaded::FlushVerticesTex3D()
 {
 	CCommandBuffer::SCommand_RenderTex3D Cmd;
-	int PrimType;
+	EPrimitiveType PrimType;
 	size_t PrimCount, NumVerts;
 	FlushVerticesImpl(false, PrimType, PrimCount, NumVerts, Cmd, sizeof(CCommandBuffer::SVertexTex3DStream));
 
@@ -111,8 +111,8 @@ CGraphics_Threaded::CGraphics_Threaded()
 	m_State.m_ClipW = 0;
 	m_State.m_ClipH = 0;
 	m_State.m_Texture = -1;
-	m_State.m_BlendMode = CCommandBuffer::BLEND_NONE;
-	m_State.m_WrapMode = CCommandBuffer::WRAP_REPEAT;
+	m_State.m_BlendMode = EBlendMode::NONE;
+	m_State.m_WrapMode = EWrapMode::REPEAT;
 
 	m_CurrentCommandBuffer = 0;
 	m_pCommandBuffer = nullptr;
@@ -126,7 +126,7 @@ CGraphics_Threaded::CGraphics_Threaded()
 	m_ScreenRefreshRate = -1;
 
 	m_Rotation = 0;
-	m_Drawing = 0;
+	m_Drawing = EDrawing::NONE;
 
 	m_TextureMemoryUsage = 0;
 
@@ -160,27 +160,27 @@ void CGraphics_Threaded::ClipDisable()
 
 void CGraphics_Threaded::BlendNone()
 {
-	m_State.m_BlendMode = CCommandBuffer::BLEND_NONE;
+	m_State.m_BlendMode = EBlendMode::NONE;
 }
 
 void CGraphics_Threaded::BlendNormal()
 {
-	m_State.m_BlendMode = CCommandBuffer::BLEND_ALPHA;
+	m_State.m_BlendMode = EBlendMode::ALPHA;
 }
 
 void CGraphics_Threaded::BlendAdditive()
 {
-	m_State.m_BlendMode = CCommandBuffer::BLEND_ADDITIVE;
+	m_State.m_BlendMode = EBlendMode::ADDITIVE;
 }
 
 void CGraphics_Threaded::WrapNormal()
 {
-	m_State.m_WrapMode = CCommandBuffer::WRAP_REPEAT;
+	m_State.m_WrapMode = EWrapMode::REPEAT;
 }
 
 void CGraphics_Threaded::WrapClamp()
 {
-	m_State.m_WrapMode = CCommandBuffer::WRAP_CLAMP;
+	m_State.m_WrapMode = EWrapMode::CLAMP;
 }
 
 uint64_t CGraphics_Threaded::TextureMemoryUsage() const
@@ -226,21 +226,21 @@ void CGraphics_Threaded::GetScreen(float *pTopLeftX, float *pTopLeftY, float *pB
 
 void CGraphics_Threaded::LinesBegin()
 {
-	dbg_assert(m_Drawing == 0, "called Graphics()->LinesBegin twice");
-	m_Drawing = DRAWING_LINES;
+	dbg_assert(m_Drawing == EDrawing::NONE, "called Graphics()->LinesBegin twice");
+	m_Drawing = EDrawing::LINES;
 	SetColor(1, 1, 1, 1);
 }
 
 void CGraphics_Threaded::LinesEnd()
 {
-	dbg_assert(m_Drawing == DRAWING_LINES, "called Graphics()->LinesEnd without begin");
+	dbg_assert(m_Drawing == EDrawing::LINES, "called Graphics()->LinesEnd without begin");
 	FlushVertices();
-	m_Drawing = 0;
+	m_Drawing = EDrawing::NONE;
 }
 
 void CGraphics_Threaded::LinesDraw(const CLineItem *pArray, size_t Num)
 {
-	dbg_assert(m_Drawing == DRAWING_LINES, "called Graphics()->LinesDraw without begin");
+	dbg_assert(m_Drawing == EDrawing::LINES, "called Graphics()->LinesDraw without begin");
 
 	size_t VertexIndex = m_NumVertices;
 	for(size_t i = 0; i < Num; ++i)
@@ -404,11 +404,11 @@ static CCommandBuffer::SCommand_Texture_Create LoadTextureCreateCommand(int Text
 
 	Cmd.m_Flags = 0;
 	if((Flags & IGraphics::TEXLOAD_TO_2D_ARRAY_TEXTURE) != 0)
-		Cmd.m_Flags |= CCommandBuffer::TEXFLAG_TO_2D_ARRAY_TEXTURE;
+		Cmd.m_Flags |= TextureFlag::TO_2D_ARRAY_TEXTURE;
 	if((Flags & IGraphics::TEXLOAD_TO_3D_TEXTURE) != 0)
-		Cmd.m_Flags |= CCommandBuffer::TEXFLAG_TO_3D_TEXTURE;
+		Cmd.m_Flags |= TextureFlag::TO_3D_TEXTURE;
 	if((Flags & IGraphics::TEXLOAD_NO_2D_TEXTURE) != 0)
-		Cmd.m_Flags |= CCommandBuffer::TEXFLAG_NO_2D_TEXTURE;
+		Cmd.m_Flags |= TextureFlag::NO_2D_TEXTURE;
 
 	return Cmd;
 }
@@ -732,7 +732,7 @@ void CGraphics_Threaded::ScreenshotDirect(bool *pSwapped)
 
 void CGraphics_Threaded::TextureSet(CTextureHandle TextureId)
 {
-	dbg_assert(m_Drawing == 0, "called Graphics()->TextureSet within begin");
+	dbg_assert(m_Drawing == EDrawing::NONE, "called Graphics()->TextureSet within begin");
 	dbg_assert(!TextureId.IsValid() || m_vTextureIndices[TextureId.Id()] == -1, "Texture handle was not invalid, but also did not correlate to an existing texture.");
 	m_State.m_Texture = TextureId.Id();
 }
@@ -750,8 +750,8 @@ void CGraphics_Threaded::Clear(float r, float g, float b, bool ForceClearNow)
 
 void CGraphics_Threaded::QuadsBegin()
 {
-	dbg_assert(m_Drawing == 0, "called Graphics()->QuadsBegin twice");
-	m_Drawing = DRAWING_QUADS;
+	dbg_assert(m_Drawing == EDrawing::NONE, "called Graphics()->QuadsBegin twice");
+	m_Drawing = EDrawing::QUADS;
 
 	QuadsSetSubset(0, 0, 1, 1);
 	QuadsSetRotation(0);
@@ -760,9 +760,9 @@ void CGraphics_Threaded::QuadsBegin()
 
 void CGraphics_Threaded::QuadsEnd()
 {
-	dbg_assert(m_Drawing == DRAWING_QUADS, "called Graphics()->QuadsEnd without begin");
+	dbg_assert(m_Drawing == EDrawing::QUADS, "called Graphics()->QuadsEnd without begin");
 	FlushVertices();
-	m_Drawing = 0;
+	m_Drawing = EDrawing::NONE;
 }
 
 void CGraphics_Threaded::QuadsTex3DBegin()
@@ -772,15 +772,15 @@ void CGraphics_Threaded::QuadsTex3DBegin()
 
 void CGraphics_Threaded::QuadsTex3DEnd()
 {
-	dbg_assert(m_Drawing == DRAWING_QUADS, "called Graphics()->QuadsEnd without begin");
+	dbg_assert(m_Drawing == EDrawing::QUADS, "called Graphics()->QuadsEnd without begin");
 	FlushVerticesTex3D();
-	m_Drawing = 0;
+	m_Drawing = EDrawing::NONE;
 }
 
 void CGraphics_Threaded::TrianglesBegin()
 {
-	dbg_assert(m_Drawing == 0, "called Graphics()->TrianglesBegin twice");
-	m_Drawing = DRAWING_TRIANGLES;
+	dbg_assert(m_Drawing == EDrawing::NONE, "called Graphics()->TrianglesBegin twice");
+	m_Drawing = EDrawing::TRIANGLES;
 
 	QuadsSetSubset(0, 0, 1, 1);
 	QuadsSetRotation(0);
@@ -789,23 +789,23 @@ void CGraphics_Threaded::TrianglesBegin()
 
 void CGraphics_Threaded::TrianglesEnd()
 {
-	dbg_assert(m_Drawing == DRAWING_TRIANGLES, "called Graphics()->TrianglesEnd without begin");
+	dbg_assert(m_Drawing == EDrawing::TRIANGLES, "called Graphics()->TrianglesEnd without begin");
 	FlushVertices();
-	m_Drawing = 0;
+	m_Drawing = EDrawing::NONE;
 }
 
 void CGraphics_Threaded::QuadsEndKeepVertices()
 {
-	dbg_assert(m_Drawing == DRAWING_QUADS, "called Graphics()->QuadsEndKeepVertices without begin");
+	dbg_assert(m_Drawing == EDrawing::QUADS, "called Graphics()->QuadsEndKeepVertices without begin");
 	FlushVertices(true);
-	m_Drawing = 0;
+	m_Drawing = EDrawing::NONE;
 }
 
 void CGraphics_Threaded::QuadsDrawCurrentVertices(bool KeepVertices)
 {
-	m_Drawing = DRAWING_QUADS;
+	m_Drawing = EDrawing::QUADS;
 	FlushVertices(KeepVertices);
-	m_Drawing = 0;
+	m_Drawing = EDrawing::NONE;
 }
 
 void CGraphics_Threaded::QuadsSetRotation(float Angle)
@@ -820,7 +820,7 @@ static unsigned char NormalizeColorComponent(float ColorComponent)
 
 void CGraphics_Threaded::SetColorVertex(const CColorVertex *pArray, size_t Num)
 {
-	dbg_assert(m_Drawing != 0, "called Graphics()->SetColorVertex without begin");
+	dbg_assert(m_Drawing != EDrawing::NONE, "called Graphics()->SetColorVertex without begin");
 
 	for(size_t i = 0; i < Num; ++i)
 	{
@@ -840,10 +840,7 @@ void CGraphics_Threaded::SetColor(float r, float g, float b, float a)
 	NewColor.g = NormalizeColorComponent(g);
 	NewColor.b = NormalizeColorComponent(b);
 	NewColor.a = NormalizeColorComponent(a);
-	for(CCommandBuffer::SColor &Color : m_aColor)
-	{
-		Color = NewColor;
-	}
+	std::fill(std::begin(m_aColor), std::end(m_aColor), NewColor);
 }
 
 void CGraphics_Threaded::SetColor(ColorRGBA Color)
@@ -946,9 +943,9 @@ void CGraphics_Threaded::QuadsTex3DDrawTL(const CQuadItem *pArray, int Num)
 
 void CGraphics_Threaded::QuadsDrawFreeform(const CFreeformItem *pArray, int Num)
 {
-	dbg_assert(m_Drawing == DRAWING_QUADS || m_Drawing == DRAWING_TRIANGLES, "called Graphics()->QuadsDrawFreeform without begin");
+	dbg_assert(m_Drawing == EDrawing::QUADS || m_Drawing == EDrawing::TRIANGLES, "called Graphics()->QuadsDrawFreeform without begin");
 
-	if((g_Config.m_GfxQuadAsTriangle && !m_GLUseTrianglesAsQuad) || m_Drawing == DRAWING_TRIANGLES)
+	if((g_Config.m_GfxQuadAsTriangle && !m_GLUseTrianglesAsQuad) || m_Drawing == EDrawing::TRIANGLES)
 	{
 		for(int i = 0; i < Num; ++i)
 		{
@@ -1725,11 +1722,11 @@ void CGraphics_Threaded::RenderQuadContainer(int ContainerIndex, int QuadOffset,
 			mem_copy(m_aVertices, &Container.m_vQuads[QuadOffset], sizeof(CCommandBuffer::SVertex) * 4 * QuadDrawNum);
 			m_NumVertices += 4 * QuadDrawNum;
 		}
-		m_Drawing = DRAWING_QUADS;
+		m_Drawing = EDrawing::QUADS;
 		if(ChangeWrapMode)
 			WrapClamp();
 		FlushVertices(false);
-		m_Drawing = 0;
+		m_Drawing = EDrawing::NONE;
 	}
 	WrapNormal();
 }
@@ -1846,10 +1843,10 @@ void CGraphics_Threaded::RenderQuadContainerEx(int ContainerIndex, int QuadOffse
 				m_NumVertices += 4;
 			}
 		}
-		m_Drawing = DRAWING_QUADS;
+		m_Drawing = EDrawing::QUADS;
 		WrapClamp();
 		FlushVertices(false);
-		m_Drawing = 0;
+		m_Drawing = EDrawing::NONE;
 	}
 	WrapNormal();
 }
@@ -2194,25 +2191,37 @@ void CGraphics_Threaded::IndicesNumRequiredNotify(unsigned int RequiredIndicesCo
 
 int CGraphics_Threaded::IssueInit()
 {
+	// The flags have to be kept consistent with flags set in the CGraphicsBackend_SDL_GL::SetWindowParams function!
+
 	bool IsPurelyWindowed = g_Config.m_GfxFullscreen == 0;
 	bool IsExclusiveFullscreen = g_Config.m_GfxFullscreen == 1;
 	bool IsDesktopFullscreen = g_Config.m_GfxFullscreen == 2;
 #ifndef CONF_FAMILY_WINDOWS
-	//  special mode for windows only
+	//  Windowed fullscreen is only available on Windows, use desktop fullscreen on other platforms
 	IsDesktopFullscreen |= g_Config.m_GfxFullscreen == 3;
 #endif
 
 	int Flags = 0;
-	if(g_Config.m_GfxBorderless)
-		Flags |= IGraphicsBackend::INITFLAG_BORDERLESS;
 	if(IsExclusiveFullscreen)
+	{
 		Flags |= IGraphicsBackend::INITFLAG_FULLSCREEN;
+	}
 	else if(IsDesktopFullscreen)
+	{
 		Flags |= IGraphicsBackend::INITFLAG_DESKTOP_FULLSCREEN;
-	if(IsPurelyWindowed)
+	}
+	else if(IsPurelyWindowed)
+	{
 		Flags |= IGraphicsBackend::INITFLAG_RESIZABLE;
+		if(g_Config.m_GfxBorderless)
+		{
+			Flags |= IGraphicsBackend::INITFLAG_BORDERLESS;
+		}
+	}
 	if(g_Config.m_GfxVsync)
+	{
 		Flags |= IGraphicsBackend::INITFLAG_VSYNC;
+	}
 
 	const int Result = m_pBackend->Init("DDNet Client", &g_Config.m_GfxScreen, &g_Config.m_GfxScreenWidth, &g_Config.m_GfxScreenHeight, &g_Config.m_GfxScreenRefreshRate, &g_Config.m_GfxFsaaSamples, Flags, &g_Config.m_GfxDesktopWidth, &g_Config.m_GfxDesktopHeight, &m_ScreenWidth, &m_ScreenHeight, m_pStorage);
 	AddBackEndWarningIfExists();
@@ -2516,15 +2525,6 @@ void CGraphics_Threaded::Minimize()
 		PropChangedListener();
 }
 
-void CGraphics_Threaded::Maximize()
-{
-	// TODO: SDL
-	m_pBackend->Maximize();
-
-	for(auto &PropChangedListener : m_vPropChangeListeners)
-		PropChangedListener();
-}
-
 void CGraphics_Threaded::WarnPngliteIncompatibleImages(bool Warn)
 {
 	m_WarnPngliteIncompatibleImages = Warn;
@@ -2544,9 +2544,9 @@ void CGraphics_Threaded::SetWindowParams(int FullscreenMode, bool IsBorderless)
 		PropChangedListener();
 }
 
-bool CGraphics_Threaded::SetWindowScreen(int Index)
+bool CGraphics_Threaded::SetWindowScreen(int Index, bool MoveToCenter)
 {
-	if(!m_pBackend->SetWindowScreen(Index))
+	if(!m_pBackend->SetWindowScreen(Index, MoveToCenter))
 	{
 		return false;
 	}
@@ -2560,29 +2560,37 @@ bool CGraphics_Threaded::SetWindowScreen(int Index)
 	return true;
 }
 
-bool CGraphics_Threaded::SwitchWindowScreen(int Index)
+bool CGraphics_Threaded::SwitchWindowScreen(int Index, bool MoveToCenter)
 {
 	const int IsFullscreen = g_Config.m_GfxFullscreen;
 	const int IsBorderless = g_Config.m_GfxBorderless;
+	const bool IsPurelyWindowed = IsFullscreen == 0 && !IsBorderless;
 
-	if(!SetWindowScreen(Index))
+	if(!SetWindowScreen(Index, !IsPurelyWindowed || MoveToCenter))
 	{
 		return false;
 	}
 
-	// Prevent window from being stretched over multiple monitors by temporarily switching to
-	// windowed fullscreen mode on Windows, which is desktop fullscreen mode on other systems.
-	SetWindowParams(3, false);
+	if(IsFullscreen != 3 && !IsPurelyWindowed)
+	{
+		// Prevent window from being stretched over multiple monitors by temporarily switching to
+		// windowed fullscreen mode on Windows, which is desktop fullscreen mode on other systems.
+		SetWindowParams(3, false);
+	}
 
-	CVideoMode CurMode;
-	GetCurrentVideoMode(CurMode, Index);
+	// In purely windowed mode we preserve the window's size instead of resizing to the screen.
+	if(!IsPurelyWindowed)
+	{
+		CVideoMode CurMode;
+		GetCurrentVideoMode(CurMode, Index);
 
-	g_Config.m_GfxColorDepth = CurMode.m_Red + CurMode.m_Green + CurMode.m_Blue > 16 ? 24 : 16;
-	g_Config.m_GfxScreenWidth = CurMode.m_WindowWidth;
-	g_Config.m_GfxScreenHeight = CurMode.m_WindowHeight;
-	g_Config.m_GfxScreenRefreshRate = CurMode.m_RefreshRate;
+		g_Config.m_GfxColorDepth = CurMode.m_Red + CurMode.m_Green + CurMode.m_Blue > 16 ? 24 : 16;
+		g_Config.m_GfxScreenWidth = CurMode.m_WindowWidth;
+		g_Config.m_GfxScreenHeight = CurMode.m_WindowHeight;
+		g_Config.m_GfxScreenRefreshRate = CurMode.m_RefreshRate;
 
-	ResizeToScreen();
+		ResizeToScreen();
+	}
 
 	SetWindowParams(IsFullscreen, IsBorderless);
 	return true;
