@@ -1757,6 +1757,7 @@ public:
 							// we hit the end, only render ellipsis and finish
 							pTmp = pEllipsis;
 							NextCharacter = 0x2026;
+							pCursor->m_Truncated = true;
 							continue;
 						}
 					}
@@ -1767,6 +1768,7 @@ public:
 					{
 						// we hit the end of the line, no more to render or count
 						pCurrent = pEnd;
+						pCursor->m_Truncated = true;
 						break;
 					}
 
@@ -2309,7 +2311,7 @@ public:
 			if(pTextContainer->m_ContainerIndex.Valid() && pTextContainer->m_ContainerIndex.m_UseCount.use_count() <= 1)
 			{
 				log_error("textrender", "Found non empty text container with index %d with %" PRIzu " quads '%s'", pTextContainer->m_StringInfo.m_QuadBufferContainerIndex, pTextContainer->m_StringInfo.m_vCharacterQuads.size(), pTextContainer->m_aDebugText);
-				dbg_assert(false, "Text container was forgotten by the implementation (the index was overwritten).");
+				dbg_assert_failed("Text container was forgotten by the implementation (the index was overwritten).");
 			}
 		}
 	}
