@@ -1,11 +1,12 @@
 #ifndef ENGINE_GHOST_H
 #define ENGINE_GHOST_H
 
-#include <base/hash.h>
-#include <engine/shared/protocol.h>
-
 #include "kernel.h"
 
+#include <base/hash.h>
+
+#include <engine/shared/protocol.h>
+
 class CGhostInfo
 {
 public:
@@ -19,8 +20,6 @@ class IGhostRecorder : public IInterface
 {
 	MACRO_INTERFACE("ghostrecorder")
 public:
-	virtual ~IGhostRecorder() = default;
-
 	virtual int Start(const char *pFilename, const char *pMap, const SHA256_DIGEST &MapSha256, const char *pName) = 0;
 	virtual void Stop(int Ticks, int Time) = 0;
 
@@ -32,8 +31,6 @@ class IGhostLoader : public IInterface
 {
 	MACRO_INTERFACE("ghostloader")
 public:
-	virtual ~IGhostLoader() = default;
-
 	virtual bool Load(const char *pFilename, const char *pMap, const SHA256_DIGEST &MapSha256, unsigned MapCrc) = 0;
 	virtual void Close() = 0;
 
