@@ -11,6 +11,33 @@
 #define MOD_IDENT "default_mod"
 #define HELPER_IDENT "default_helper"
 
+const char *CAuthManager::AuthLevelToRoleName(int AuthLevel)
+{
+	switch(AuthLevel)
+	{
+	case AUTHED_ADMIN:
+		return RoleName::ADMIN;
+	case AUTHED_MOD:
+		return RoleName::MODERATOR;
+	case AUTHED_HELPER:
+		return RoleName::HELPER;
+	}
+
+	dbg_assert_failed("Invalid auth level: %d", AuthLevel);
+}
+
+static int RoleNameToAuthLevel(const char *pRoleName)
+{
+	if(!str_comp(pRoleName, RoleName::ADMIN))
+		return AUTHED_ADMIN;
+	if(!str_comp(pRoleName, RoleName::MODERATOR))
+		return AUTHED_MOD;
+	if(!str_comp(pRoleName, RoleName::HELPER))
+		return AUTHED_HELPER;
+
+	dbg_assert_failed("Invalid role name: %s", pRoleName);
+}
+
 static MD5_DIGEST HashPassword(const char *pPassword, const unsigned char aSalt[SALT_BYTES])
 {
 	// Hash the password and the salt
@@ -27,6 +54,10 @@ CAuthManager::CAuthManager()
 	m_aDefault[1] = -1;
 	m_aDefault[2] = -1;
 	m_Generated = false;
+
+	AddRole(RoleName::ADMIN, RoleRank::ADMIN);
+	AddRole(RoleName::MODERATOR, RoleRank::MODERATOR);
+	AddRole(RoleName::HELPER, RoleRank::HELPER);
 }
 
 void CAuthManager::Init()
@@ -46,12 +77,12 @@ void CAuthManager::Init()
 	if(m_vKeys.size() == NumDefaultKeys && !g_Config.m_SvRconPassword[0])
 	{
 		secure_random_password(g_Config.m_SvRconPassword, sizeof(g_Config.m_SvRconPassword), 6);
-		AddDefaultKey(AUTHED_ADMIN, g_Config.m_SvRconPassword);
+		AddDefaultKey(RoleName::ADMIN, g_Config.m_SvRconPassword);
 		m_Generated = true;
 	}
 }
 
-int CAuthManager::AddKeyHash(const char *pIdent, MD5_DIGEST Hash, const unsigned char *pSalt, int AuthLevel)
+int CAuthManager::AddKeyHash(const char *pIdent, MD5_DIGEST Hash, const unsigned char *pSalt, const char *pRoleName)
 {
 	if(FindKey(pIdent) >= 0)
 		return -1;
@@ -60,18 +91,19 @@ int CAuthManager::AddKeyHash(const char *pIdent, MD5_DIGEST Hash, const unsigned
 	str_copy(Key.m_aIdent, pIdent);
 	Key.m_Pw = Hash;
 	mem_copy(Key.m_aSalt, pSalt, SALT_BYTES);
-	Key.m_Level = AuthLevel;
+	Key.m_pRole = FindRole(pRoleName);
+	dbg_assert(Key.m_pRole != nullptr, "Invalid role name '%s'.", pRoleName);
 
 	m_vKeys.push_back(Key);
 	return m_vKeys.size() - 1;
 }
 
-int CAuthManager::AddKey(const char *pIdent, const char *pPw, int AuthLevel)
+int CAuthManager::AddKey(const char *pIdent, const char *pPw, const char *pRoleName)
 {
 	// Generate random salt
 	unsigned char aSalt[SALT_BYTES];
 	secure_random_fill(aSalt, SALT_BYTES);
-	return AddKeyHash(pIdent, HashPassword(pPw, aSalt), aSalt, AuthLevel);
+	return AddKeyHash(pIdent, HashPassword(pPw, aSalt), aSalt, pRoleName);
 }
 
 void CAuthManager::RemoveKey(int Slot)
@@ -107,18 +139,27 @@ bool CAuthManager::CheckKey(int Slot, const char *pPw) const
 	return m_vKeys[Slot].m_Pw == HashPassword(pPw, m_vKeys[Slot].m_aSalt);
 }
 
-int CAuthManager::DefaultKey(int AuthLevel) const
+int CAuthManager::DefaultIndex(int AuthLevel) const
 {
-	if(AuthLevel < 0 || AuthLevel > AUTHED_ADMIN)
-		return 0;
-	return m_aDefault[AUTHED_ADMIN - AuthLevel];
+	return std::size(m_aDefault) - AuthLevel;
+}
+
+int CAuthManager::DefaultKey(const char *pRoleName) const
+{
+	if(!str_comp(pRoleName, RoleName::ADMIN))
+		return m_aDefault[DefaultIndex(AUTHED_ADMIN)];
+	if(!str_comp(pRoleName, RoleName::MODERATOR))
+		return m_aDefault[DefaultIndex(AUTHED_MOD)];
+	if(!str_comp(pRoleName, RoleName::HELPER))
+		return m_aDefault[DefaultIndex(AUTHED_HELPER)];
+	return 0;
 }
 
 int CAuthManager::KeyLevel(int Slot) const
 {
 	if(Slot < 0 || Slot >= (int)m_vKeys.size())
 		return false;
-	return m_vKeys[Slot].m_Level;
+	return m_vKeys[Slot].m_pRole->Rank();
 }
 
 const char *CAuthManager::KeyIdent(int Slot) const
@@ -133,7 +174,7 @@ bool CAuthManager::IsValidIdent(const char *pIdent) const
 	return str_length(pIdent) < (int)sizeof(CKey().m_aIdent);
 }
 
-void CAuthManager::UpdateKeyHash(int Slot, MD5_DIGEST Hash, const unsigned char *pSalt, int AuthLevel)
+void CAuthManager::UpdateKeyHash(int Slot, MD5_DIGEST Hash, const unsigned char *pSalt, const char *pRoleName)
 {
 	if(Slot < 0 || Slot >= (int)m_vKeys.size())
 		return;
@@ -141,10 +182,10 @@ void CAuthManager::UpdateKeyHash(int Slot, MD5_DIGEST Hash, const unsigned char
 	CKey *pKey = &m_vKeys[Slot];
 	pKey->m_Pw = Hash;
 	mem_copy(pKey->m_aSalt, pSalt, SALT_BYTES);
-	pKey->m_Level = AuthLevel;
+	pKey->m_pRole = FindRole(pRoleName);
 }
 
-void CAuthManager::UpdateKey(int Slot, const char *pPw, int AuthLevel)
+void CAuthManager::UpdateKey(int Slot, const char *pPw, const char *pRoleName)
 {
 	if(Slot < 0 || Slot >= (int)m_vKeys.size())
 		return;
@@ -152,25 +193,25 @@ void CAuthManager::UpdateKey(int Slot, const char *pPw, int AuthLevel)
 	// Generate random salt
 	unsigned char aSalt[SALT_BYTES];
 	secure_random_fill(aSalt, SALT_BYTES);
-	UpdateKeyHash(Slot, HashPassword(pPw, aSalt), aSalt, AuthLevel);
+	UpdateKeyHash(Slot, HashPassword(pPw, aSalt), aSalt, pRoleName);
 }
 
 void CAuthManager::ListKeys(FListCallback pfnListCallback, void *pUser)
 {
 	for(auto &Key : m_vKeys)
-		pfnListCallback(Key.m_aIdent, Key.m_Level, pUser);
+		pfnListCallback(Key.m_aIdent, Key.m_pRole->Name(), pUser);
 }
 
-void CAuthManager::AddDefaultKey(int Level, const char *pPw)
+void CAuthManager::AddDefaultKey(const char *pRoleName, const char *pPw)
 {
-	if(Level < AUTHED_HELPER || Level > AUTHED_ADMIN)
-		return;
+	int Level = RoleNameToAuthLevel(pRoleName);
+	dbg_assert(AUTHED_HELPER <= Level && Level <= AUTHED_ADMIN, "default role with name '%s' not found.", pRoleName);
 
 	static const char s_aaIdents[3][sizeof(HELPER_IDENT)] = {ADMIN_IDENT, MOD_IDENT, HELPER_IDENT};
 	int Index = AUTHED_ADMIN - Level;
 	if(m_aDefault[Index] >= 0)
 		return; // already exists
-	m_aDefault[Index] = AddKey(s_aaIdents[Index], pPw, Level);
+	m_aDefault[Index] = AddKey(s_aaIdents[Index], pPw, AuthLevelToRoleName(Level));
 }
 
 bool CAuthManager::IsGenerated() const
@@ -185,3 +226,20 @@ int CAuthManager::NumNonDefaultKeys() const
 	});
 	return m_vKeys.size() - DefaultCount;
 }
+
+CRconRole *CAuthManager::FindRole(const char *pName)
+{
+	auto It = m_Roles.find(pName);
+	if(It == m_Roles.end())
+		return nullptr;
+	return &It->second;
+}
+
+bool CAuthManager::AddRole(const char *pName, int Rank)
+{
+	if(FindRole(pName))
+		return false;
+
+	m_Roles.insert({pName, CRconRole(pName, Rank)});
+	return true;
+}
