@@ -184,8 +184,7 @@ const char *CRegister::ProtocolToScheme(int Protocol)
 	case PROTOCOL_TW7_IPV6: return "tw-0.7+udp://";
 	case PROTOCOL_TW7_IPV4: return "tw-0.7+udp://";
 	}
-	dbg_assert(false, "invalid protocol");
-	dbg_break();
+	dbg_assert_failed("invalid protocol");
 }
 
 const char *CRegister::ProtocolToString(int Protocol)
@@ -197,8 +196,7 @@ const char *CRegister::ProtocolToString(int Protocol)
 	case PROTOCOL_TW7_IPV6: return "tw0.7/ipv6";
 	case PROTOCOL_TW7_IPV4: return "tw0.7/ipv4";
 	}
-	dbg_assert(false, "invalid protocol");
-	dbg_break();
+	dbg_assert_failed("invalid protocol");
 }
 
 bool CRegister::ProtocolFromString(int *pResult, const char *pString)
@@ -236,8 +234,7 @@ const char *CRegister::ProtocolToSystem(int Protocol)
 	case PROTOCOL_TW7_IPV6: return "register/7/ipv6";
 	case PROTOCOL_TW7_IPV4: return "register/7/ipv4";
 	}
-	dbg_assert(false, "invalid protocol");
-	dbg_break();
+	dbg_assert_failed("invalid protocol");
 }
 
 IPRESOLVE CRegister::ProtocolToIpresolve(int Protocol)
@@ -249,8 +246,7 @@ IPRESOLVE CRegister::ProtocolToIpresolve(int Protocol)
 	case PROTOCOL_TW7_IPV6: return IPRESOLVE::V6;
 	case PROTOCOL_TW7_IPV4: return IPRESOLVE::V4;
 	}
-	dbg_assert(false, "invalid protocol");
-	dbg_break();
+	dbg_assert_failed("invalid protocol");
 }
 
 void CRegister::ConchainOnConfigChange(IConsole::IResult *pResult, void *pUserData, IConsole::FCommandCallback pfnCallback, void *pCallbackUserData)
@@ -281,7 +277,7 @@ void CRegister::CProtocol::SendRegister()
 	bool SendInfo;
 
 	{
-		CLockScope ls(m_pShared->m_pGlobal->m_Lock);
+		const CLockScope LockScope(m_pShared->m_pGlobal->m_Lock);
 		InfoSerial = m_pShared->m_pGlobal->m_InfoSerial;
 		SendInfo = InfoSerial > m_pShared->m_pGlobal->m_LatestSuccessfulInfoSerial;
 	}
@@ -321,7 +317,7 @@ void CRegister::CProtocol::SendRegister()
 
 	int RequestIndex;
 	{
-		CLockScope ls(m_pShared->m_Lock);
+		const CLockScope LockScope(m_pShared->m_Lock);
 		if(m_pShared->m_LatestResponseStatus != STATUS_OK)
 		{
 			log_info(ProtocolToSystem(m_Protocol), "registering...");
@@ -380,7 +376,7 @@ CRegister::CProtocol::CProtocol(CRegister *pParent, int Protocol) :
 
 void CRegister::CProtocol::CheckChallengeStatus()
 {
-	CLockScope ls(m_pShared->m_Lock);
+	const CLockScope LockScope(m_pShared->m_Lock);
 	// No requests in flight?
 	if(m_pShared->m_LatestResponseIndex == m_pShared->m_NumTotalRequests - 1)
 	{
@@ -474,7 +470,7 @@ void CRegister::CProtocol::CJob::Run()
 		return;
 	}
 	{
-		CLockScope ls(m_pShared->m_Lock);
+		const CLockScope LockScope(m_pShared->m_Lock);
 		if(Status != m_pShared->m_LatestResponseStatus)
 		{
 			if(Status != STATUS_OK)
@@ -500,7 +496,7 @@ void CRegister::CProtocol::CJob::Run()
 	}
 	if(Status == STATUS_OK)
 	{
-		CLockScope ls(m_pShared->m_pGlobal->m_Lock);
+		const CLockScope LockScope(m_pShared->m_pGlobal->m_Lock);
 		if(m_InfoSerial > m_pShared->m_pGlobal->m_LatestSuccessfulInfoSerial)
 		{
 			m_pShared->m_pGlobal->m_LatestSuccessfulInfoSerial = m_InfoSerial;
@@ -508,7 +504,7 @@ void CRegister::CProtocol::CJob::Run()
 	}
 	else if(Status == STATUS_NEEDINFO)
 	{
-		CLockScope ls(m_pShared->m_pGlobal->m_Lock);
+		const CLockScope LockScope(m_pShared->m_pGlobal->m_Lock);
 		if(m_InfoSerial == m_pShared->m_pGlobal->m_LatestSuccessfulInfoSerial)
 		{
 			// Tell other requests that they need to send the info again.
@@ -530,7 +526,7 @@ CRegister::CRegister(CConfig *pConfig, IConsole *pConsole, IEngine *pEngine, IHt
 		CProtocol(this, PROTOCOL_TW7_IPV4),
 	}
 {
-	const int HEADER_LEN = sizeof(SERVERBROWSE_CHALLENGE);
+	static constexpr int HEADER_LEN = sizeof(SERVERBROWSE_CHALLENGE);
 	mem_copy(m_aVerifyPacketPrefix, SERVERBROWSE_CHALLENGE, HEADER_LEN);
 	FormatUuid(m_ChallengeSecret, m_aVerifyPacketPrefix + HEADER_LEN, sizeof(m_aVerifyPacketPrefix) - HEADER_LEN);
 	m_aVerifyPacketPrefix[HEADER_LEN + UUID_MAXSTRSIZE - 1] = ':';
@@ -734,7 +730,7 @@ void CRegister::OnNewInfo(const char *pInfo)
 	m_GotServerInfo = true;
 	str_copy(m_aServerInfo, pInfo);
 	{
-		CLockScope ls(m_pGlobal->m_Lock);
+		const CLockScope LockScope(m_pGlobal->m_Lock);
 		m_pGlobal->m_InfoSerial += 1;
 	}
 
