@@ -28,7 +28,7 @@ CConsole::CResult::CResult(int ClientId) :
 	mem_zero(m_aStringStorage, sizeof(m_aStringStorage));
 	m_pArgsStart = nullptr;
 	m_pCommand = nullptr;
-	mem_zero(m_apArgs, sizeof(m_apArgs));
+	std::fill(std::begin(m_apArgs), std::end(m_apArgs), nullptr);
 }
 
 CConsole::CResult::CResult(const CResult &Other) :
@@ -66,21 +66,23 @@ int CConsole::CResult::GetInteger(unsigned Index) const
 {
 	if(Index >= m_NumArgs)
 		return 0;
-	return str_toint(m_apArgs[Index]);
+	int Out;
+	return str_toint(m_apArgs[Index], &Out) ? Out : 0;
 }
 
 float CConsole::CResult::GetFloat(unsigned Index) const
 {
 	if(Index >= m_NumArgs)
 		return 0.0f;
-	return str_tofloat(m_apArgs[Index]);
+	float Out;
+	return str_tofloat(m_apArgs[Index], &Out) ? Out : 0.0f;
 }
 
-std::optional<ColorHSLA> CConsole::CResult::GetColor(unsigned Index, float DarkestLighting) const
+ColorHSLA CConsole::CResult::GetColor(unsigned Index, float DarkestLighting) const
 {
 	if(Index >= m_NumArgs)
-		return std::nullopt;
-	return ColorParse(m_apArgs[Index], DarkestLighting);
+		return ColorHSLA(0, 0, 0);
+	return ColorParse(m_apArgs[Index], DarkestLighting).value_or(ColorHSLA(0, 0, 0));
 }
 
 void CConsole::CCommand::SetAccessLevel(EAccessLevel AccessLevel)
@@ -88,23 +90,23 @@ void CConsole::CCommand::SetAccessLevel(EAccessLevel AccessLevel)
 	m_AccessLevel = AccessLevel;
 }
 
-const IConsole::ICommandInfo *CConsole::FirstCommandInfo(EAccessLevel AccessLevel, int FlagMask) const
+const IConsole::ICommandInfo *CConsole::FirstCommandInfo(int ClientId, int FlagMask) const
 {
 	for(const CCommand *pCommand = m_pFirstCommand; pCommand; pCommand = pCommand->Next())
 	{
-		if(pCommand->m_Flags & FlagMask && pCommand->GetAccessLevel() >= AccessLevel)
+		if(pCommand->m_Flags & FlagMask && CanUseCommand(ClientId, pCommand))
 			return pCommand;
 	}
 
 	return nullptr;
 }
 
-const IConsole::ICommandInfo *CConsole::NextCommandInfo(const IConsole::ICommandInfo *pInfo, EAccessLevel AccessLevel, int FlagMask) const
+const IConsole::ICommandInfo *CConsole::NextCommandInfo(const IConsole::ICommandInfo *pInfo, int ClientId, int FlagMask) const
 {
 	const CCommand *pNext = ((CCommand *)pInfo)->Next();
 	while(pNext)
 	{
-		if(pNext->m_Flags & FlagMask && pNext->GetAccessLevel() >= AccessLevel)
+		if(pNext->m_Flags & FlagMask && CanUseCommand(ClientId, pNext))
 			break;
 		pNext = pNext->Next();
 	}
@@ -148,8 +150,7 @@ const char *CConsole::AccessLevelToString(EAccessLevel AccessLevel)
 	case EAccessLevel::USER:
 		return "all";
 	}
-	dbg_assert(false, "invalid access level: %d", (int)AccessLevel);
-	dbg_break();
+	dbg_assert_failed("invalid access level: %d", (int)AccessLevel);
 }
 
 // the maximum number of tokens occurs in a string of length CONSOLE_MAX_STR_LENGTH with tokens size 1 separated by single spaces
@@ -275,9 +276,17 @@ int CConsole::ParseArgs(CResult *pResult, const char *pFormat, bool IsColor)
 				}
 
 				// validate args
+				if(IsColor)
+				{
+					auto Color = ColorParse(pResult->GetString(pResult->NumArguments() - 1), 0.0f);
+					if(!Color.has_value())
+					{
+						Error = PARSEARGS_INVALID_COLOR;
+						break;
+					}
+				}
 				if(Command == 'i')
 				{
-					// don't validate colors here
 					if(!IsColor)
 					{
 						int Value;
@@ -397,6 +406,12 @@ void CConsole::SetUnknownCommandCallback(FUnknownCommandCallback pfnCallback, vo
 	m_pUnknownCommandUserdata = pUser;
 }
 
+void CConsole::SetCanUseCommandCallback(FCanUseCommandCallback pfnCallback, void *pUser)
+{
+	m_pfnCanUseCommandCallback = pfnCallback;
+	m_pCanUseCommandUserData = pUser;
+}
+
 void CConsole::InitChecksum(CChecksumData *pData) const
 {
 	pData->m_NumCommands = 0;
@@ -415,11 +430,6 @@ void CConsole::InitChecksum(CChecksumData *pData) const
 	}
 }
 
-void CConsole::SetAccessLevel(EAccessLevel AccessLevel)
-{
-	m_AccessLevel = AccessLevel;
-}
-
 bool CConsole::LineIsValid(const char *pStr)
 {
 	if(!pStr || *pStr == 0)
@@ -427,7 +437,7 @@ bool CConsole::LineIsValid(const char *pStr)
 
 	do
 	{
-		CResult Result(-1);
+		CResult Result(IConsole::CLIENT_ID_UNSPECIFIED);
 		const char *pEnd = pStr;
 		const char *pNextPart = nullptr;
 		int InString = 0;
@@ -547,7 +557,7 @@ void CConsole::ExecuteLineStroked(int Stroke, const char *pStr, int ClientId, bo
 					Print(OUTPUT_LEVEL_STANDARD, "console", aBuf);
 				}
 			}
-			else if(pCommand->GetAccessLevel() >= m_AccessLevel)
+			else if(CanUseCommand(Result.m_ClientId, pCommand))
 			{
 				int IsStrokeCommand = 0;
 				if(Result.m_pCommand[0] == '+')
@@ -572,6 +582,8 @@ void CConsole::ExecuteLineStroked(int Stroke, const char *pStr, int ClientId, bo
 						char aBuf[CMDLINE_LENGTH + 64];
 						if(Error == PARSEARGS_INVALID_INTEGER)
 							str_format(aBuf, sizeof(aBuf), "%s is not a valid integer.", Result.GetString(Result.NumArguments() - 1));
+						else if(Error == PARSEARGS_INVALID_COLOR)
+							str_format(aBuf, sizeof(aBuf), "%s is not a valid color.", Result.GetString(Result.NumArguments() - 1));
 						else if(Error == PARSEARGS_INVALID_FLOAT)
 							str_format(aBuf, sizeof(aBuf), "%s is not a valid decimal number.", Result.GetString(Result.NumArguments() - 1));
 						else
@@ -642,6 +654,14 @@ void CConsole::ExecuteLineStroked(int Stroke, const char *pStr, int ClientId, bo
 	}
 }
 
+bool CConsole::CanUseCommand(int ClientId, const IConsole::ICommandInfo *pCommand) const
+{
+	// the fallback is needed for the client and rust tests
+	if(!m_pfnCanUseCommandCallback)
+		return true;
+	return m_pfnCanUseCommandCallback(ClientId, pCommand, m_pCanUseCommandUserData);
+}
+
 int CConsole::PossibleCommands(const char *pStr, int FlagMask, bool Temp, FPossibleCallback pfnCallback, void *pUser)
 {
 	int Index = 0;
@@ -741,7 +761,7 @@ void CConsole::Con_Echo(IResult *pResult, void *pUserData)
 
 void CConsole::Con_Exec(IResult *pResult, void *pUserData)
 {
-	((CConsole *)pUserData)->ExecuteFile(pResult->GetString(0), -1, true, IStorage::TYPE_ALL);
+	((CConsole *)pUserData)->ExecuteFile(pResult->GetString(0), pResult->m_ClientId, true, IStorage::TYPE_ALL);
 }
 
 void CConsole::ConCommandAccess(IResult *pResult, void *pUser)
@@ -843,7 +863,6 @@ void CConsole::TraverseChain(FCommandCallback *ppfnCallback, void **ppUserData)
 CConsole::CConsole(int FlagMask)
 {
 	m_FlagMask = FlagMask;
-	m_AccessLevel = EAccessLevel::ADMIN;
 	m_pRecycleList = nullptr;
 	m_TempCommands.Reset();
 	m_StoreCommands = true;
@@ -907,7 +926,7 @@ void CConsole::ParseArguments(int NumArgs, const char **ppArguments)
 		if(ppArguments[i][0] == '-' && ppArguments[i][1] == 'f' && ppArguments[i][2] == 0)
 		{
 			if(NumArgs - i > 1)
-				ExecuteFile(ppArguments[i + 1], -1, true, IStorage::TYPE_ABSOLUTE);
+				ExecuteFile(ppArguments[i + 1], IConsole::CLIENT_ID_UNSPECIFIED, true, IStorage::TYPE_ABSOLUTE);
 			i++;
 		}
 		else if(!str_comp("-s", ppArguments[i]) || !str_comp("--silent", ppArguments[i]))
