@@ -133,7 +133,7 @@ static const unsigned char NET_HEADER_EXTENDED[] = {'x', 'e'};
 void CNetBase::SendPacketConnless(NETSOCKET Socket, NETADDR *pAddr, const void *pData, int DataSize, bool Extended, unsigned char aExtra[NET_CONNLESS_EXTRA_SIZE])
 {
 	unsigned char aBuffer[NET_MAX_PACKETSIZE];
-	const int DATA_OFFSET = sizeof(NET_HEADER_EXTENDED) + NET_CONNLESS_EXTRA_SIZE;
+	static constexpr int DATA_OFFSET = sizeof(NET_HEADER_EXTENDED) + NET_CONNLESS_EXTRA_SIZE;
 	dbg_assert(DataSize <= (int)sizeof(aBuffer) - DATA_OFFSET,
 		"Invalid DataSize for CNetBase::SendPacketConnless: %d > %d", DataSize, (int)sizeof(aBuffer) - DATA_OFFSET);
 
@@ -153,7 +153,7 @@ void CNetBase::SendPacketConnless(NETSOCKET Socket, NETADDR *pAddr, const void *
 void CNetBase::SendPacketConnlessWithToken7(NETSOCKET Socket, NETADDR *pAddr, const void *pData, int DataSize, SECURITY_TOKEN Token, SECURITY_TOKEN ResponseToken)
 {
 	unsigned char aBuffer[NET_MAX_PACKETSIZE];
-	const int DATA_OFFSET = 1 + 2 * sizeof(SECURITY_TOKEN);
+	static constexpr int DATA_OFFSET = 1 + 2 * sizeof(SECURITY_TOKEN);
 	dbg_assert(DataSize <= (int)sizeof(aBuffer) - DATA_OFFSET,
 		"Invalid DataSize for CNetBase::SendPacketConnlessWithToken7: %d > %d", DataSize, (int)sizeof(aBuffer) - DATA_OFFSET);
 
@@ -168,7 +168,7 @@ void CNetBase::SendPacket(NETSOCKET Socket, NETADDR *pAddr, CNetPacketConstruct
 {
 	dbg_assert(IsValidConnectionOrientedPacket(pPacket), "Invalid packet to send. Flags=%d Ack=%d NumChunks=%d Size=%d",
 		pPacket->m_Flags, pPacket->m_Ack, pPacket->m_NumChunks, pPacket->m_DataSize);
-	dbg_assert((pPacket->m_Flags & NET_PACKETFLAG_COMPRESSION) == 0, "Do not set NET_PACKETFLAG_COMPRESSION, it will be set automatically when approriate");
+	dbg_assert((pPacket->m_Flags & NET_PACKETFLAG_COMPRESSION) == 0, "Do not set NET_PACKETFLAG_COMPRESSION, it will be set automatically when appropriate");
 
 	unsigned char aBuffer[NET_MAX_PACKETSIZE];
 
@@ -389,7 +389,7 @@ void CNetBase::SendControlMsgWithToken7(NETSOCKET Socket, NETADDR *pAddr, TOKEN
 	aRequestTokenBuf[0] = (MyToken >> 24) & 0xff;
 	aRequestTokenBuf[1] = (MyToken >> 16) & 0xff;
 	aRequestTokenBuf[2] = (MyToken >> 8) & 0xff;
-	aRequestTokenBuf[3] = (MyToken)&0xff;
+	aRequestTokenBuf[3] = (MyToken) & 0xff;
 	const int Size = Extended ? sizeof(aRequestTokenBuf) : sizeof(TOKEN);
 	CNetBase::SendControlMsg(Socket, pAddr, Ack, ControlMsg, aRequestTokenBuf, Size, Token, true);
 }
