@@ -221,7 +221,7 @@ public:
 class CNetConnection
 {
 	// TODO: is this needed because this needs to be aware of
-	// the ack sequencing number and is also responible for updating
+	// the ack sequencing number and is also responsible for updating
 	// that. this should be fixed.
 	friend class CNetRecvUnpacker;
 
@@ -328,7 +328,7 @@ public:
 	int SecurityToken() const { return m_SecurityToken; }
 	CStaticRingBuffer<CNetChunkResend, NET_CONN_BUFFERSIZE> *ResendBuffer() { return &m_Buffer; }
 
-	void SetTimedOut(const NETADDR *pAddr, int Sequence, int Ack, SECURITY_TOKEN SecurityToken, CStaticRingBuffer<CNetChunkResend, NET_CONN_BUFFERSIZE> *pResendBuffer, bool Sixup);
+	void ResumeConnection(const NETADDR *pAddr, int Sequence, int Ack, SECURITY_TOKEN SecurityToken, CStaticRingBuffer<CNetChunkResend, NET_CONN_BUFFERSIZE> *pResendBuffer, bool Sixup);
 
 	// anti spoof
 	void DirectInit(const NETADDR &Addr, SECURITY_TOKEN SecurityToken, SECURITY_TOKEN Token, bool Sixup);
@@ -477,8 +477,9 @@ public:
 
 	//
 	void SetMaxClientsPerIp(int Max);
-	bool SetTimedOut(int ClientId, int OrigId);
-	void SetTimeoutProtected(int ClientId);
+	bool HasErrored(int ClientId);
+	void ResumeOldConnection(int ClientId, int OrigId);
+	void IgnoreTimeouts(int ClientId);
 
 	void ResetErrorString(int ClientId);
 	const char *ErrorString(int ClientId);
@@ -571,7 +572,7 @@ class CNetClient
 	CStun *m_pStun = nullptr;
 
 public:
-	NETSOCKET m_Socket;
+	NETSOCKET m_Socket = nullptr;
 	// openness
 	bool Open(NETADDR BindAddr);
 	void Close();
