@@ -698,7 +698,7 @@ int CNetServer::Send(CNetChunk *pChunk)
 		int Flags = 0;
 		dbg_assert(
 			pChunk->m_ClientId >= 0 && pChunk->m_ClientId < MaxClients(),
-			"erroneous client id %d",
+			"Invalid pChunk->m_ClientId: %d",
 			pChunk->m_ClientId);
 
 		if(pChunk->m_Flags & NETSENDFLAG_VITAL)
@@ -709,10 +709,6 @@ int CNetServer::Send(CNetChunk *pChunk)
 			if(pChunk->m_Flags & NETSENDFLAG_FLUSH)
 				m_aSlots[pChunk->m_ClientId].m_Connection.Flush();
 		}
-		else
-		{
-			//Drop(pChunk->m_ClientId, "Error sending data");
-		}
 	}
 	return 0;
 }
@@ -730,17 +726,18 @@ void CNetServer::SetMaxClientsPerIp(int Max)
 	m_MaxClientsPerIp = std::clamp<int>(Max, 1, NET_MAX_CLIENTS);
 }
 
-bool CNetServer::SetTimedOut(int ClientId, int OrigId)
+bool CNetServer::HasErrored(int ClientId)
 {
-	if(m_aSlots[ClientId].m_Connection.State() != CNetConnection::EState::ERROR)
-		return false;
-
-	m_aSlots[ClientId].m_Connection.SetTimedOut(ClientAddr(OrigId), m_aSlots[OrigId].m_Connection.SeqSequence(), m_aSlots[OrigId].m_Connection.AckSequence(), m_aSlots[OrigId].m_Connection.SecurityToken(), m_aSlots[OrigId].m_Connection.ResendBuffer(), m_aSlots[OrigId].m_Connection.m_Sixup);
-	m_aSlots[OrigId].m_Connection.Reset();
-	return true;
+	return m_aSlots[ClientId].m_Connection.State() == CNetConnection::EState::ERROR;
 }
 
-void CNetServer::SetTimeoutProtected(int ClientId)
+void CNetServer::ResumeOldConnection(int ClientId, int OrigId)
+{
+	m_aSlots[ClientId].m_Connection.ResumeConnection(ClientAddr(OrigId), m_aSlots[OrigId].m_Connection.SeqSequence(), m_aSlots[OrigId].m_Connection.AckSequence(), m_aSlots[OrigId].m_Connection.SecurityToken(), m_aSlots[OrigId].m_Connection.ResendBuffer(), m_aSlots[OrigId].m_Connection.m_Sixup);
+	m_aSlots[OrigId].m_Connection.Reset();
+}
+
+void CNetServer::IgnoreTimeouts(int ClientId)
 {
 	m_aSlots[ClientId].m_Connection.m_TimeoutProtected = true;
 }
