@@ -433,7 +433,7 @@ public:
 		}
 		else
 		{
-			dbg_assert(false, "Type invalid");
+			dbg_assert_failed("Type invalid");
 		}
 	}
 
@@ -472,7 +472,7 @@ public:
 		}
 		else
 		{
-			dbg_assert(false, "Type invalid");
+			dbg_assert_failed("Type invalid");
 		}
 	}
 
@@ -549,8 +549,7 @@ public:
 		}
 		else
 		{
-			dbg_assert(false, "Type invalid");
-			return nullptr;
+			dbg_assert_failed("Type invalid");
 		}
 	}
 
@@ -577,8 +576,7 @@ public:
 		}
 		else
 		{
-			dbg_assert(false, "Type invalid");
-			return false;
+			dbg_assert_failed("Type invalid");
 		}
 	}
 
@@ -728,7 +726,7 @@ public:
 		}
 		else
 		{
-			dbg_assert(false, "Type invalid");
+			dbg_assert_failed("Type invalid");
 		}
 
 		return pBuffer[0] != 0;
@@ -791,7 +789,7 @@ public:
 		}
 		else
 		{
-			dbg_assert(false, "Type invalid");
+			dbg_assert_failed("Type invalid");
 		}
 
 		return pEntries->size();
