@@ -44,7 +44,7 @@ CBinds::~CBinds()
 void CBinds::Bind(int KeyId, const char *pStr, bool FreeOnly, int ModifierCombination)
 {
 	dbg_assert(KeyId >= KEY_FIRST && KeyId < KEY_LAST, "KeyId invalid");
-	dbg_assert(ModifierCombination >= MODIFIER_NONE && ModifierCombination < MODIFIER_COMBINATION_COUNT, "ModifierCombination invalid");
+	dbg_assert(ModifierCombination >= KeyModifier::NONE && ModifierCombination < KeyModifier::COMBINATION_COUNT, "ModifierCombination invalid");
 
 	if(FreeOnly && Get(KeyId, ModifierCombination)[0])
 		return;
@@ -97,18 +97,18 @@ int CBinds::GetModifierMaskOfKey(int Key)
 	{
 	case KEY_LSHIFT:
 	case KEY_RSHIFT:
-		return 1 << CBinds::MODIFIER_SHIFT;
+		return 1 << KeyModifier::SHIFT;
 	case KEY_LCTRL:
 	case KEY_RCTRL:
-		return 1 << CBinds::MODIFIER_CTRL;
+		return 1 << KeyModifier::CTRL;
 	case KEY_LALT:
 	case KEY_RALT:
-		return 1 << CBinds::MODIFIER_ALT;
+		return 1 << KeyModifier::ALT;
 	case KEY_LGUI:
 	case KEY_RGUI:
-		return 1 << CBinds::MODIFIER_GUI;
+		return 1 << KeyModifier::GUI;
 	default:
-		return CBinds::MODIFIER_NONE;
+		return KeyModifier::NONE;
 	}
 }
 
@@ -147,11 +147,11 @@ bool CBinds::OnInput(const IInput::CEvent &Event)
 				OnKeyPress(ModifierMask);
 				Handled = true;
 			}
-			else if(m_aapKeyBindings[MODIFIER_NONE][Event.m_Key] &&
-				ModifierMask != ((1 << MODIFIER_CTRL) | (1 << MODIFIER_SHIFT)) &&
-				ModifierMask != ((1 << MODIFIER_GUI) | (1 << MODIFIER_SHIFT)))
+			else if(m_aapKeyBindings[KeyModifier::NONE][Event.m_Key] &&
+				ModifierMask != ((1 << KeyModifier::CTRL) | (1 << KeyModifier::SHIFT)) &&
+				ModifierMask != ((1 << KeyModifier::GUI) | (1 << KeyModifier::SHIFT)))
 			{
-				OnKeyPress(MODIFIER_NONE);
+				OnKeyPress(KeyModifier::NONE);
 				Handled = true;
 			}
 		}
@@ -198,7 +198,7 @@ bool CBinds::OnInput(const IInput::CEvent &Event)
 		}
 
 		// Release all active binds that use this modifier key
-		if(KeyModifierMask != MODIFIER_NONE)
+		if(KeyModifierMask != KeyModifier::NONE)
 		{
 			while(true)
 			{
@@ -229,17 +229,22 @@ void CBinds::UnbindAll()
 	}
 }
 
-const char *CBinds::Get(int KeyId, int ModifierCombination)
+const char *CBinds::Get(int KeyId, int ModifierCombination) const
 {
 	dbg_assert(KeyId >= KEY_FIRST && KeyId < KEY_LAST, "KeyId invalid");
-	dbg_assert(ModifierCombination >= MODIFIER_NONE && ModifierCombination < MODIFIER_COMBINATION_COUNT, "ModifierCombination invalid");
+	dbg_assert(ModifierCombination >= KeyModifier::NONE && ModifierCombination < KeyModifier::COMBINATION_COUNT, "ModifierCombination invalid");
 	return m_aapKeyBindings[ModifierCombination][KeyId] ? m_aapKeyBindings[ModifierCombination][KeyId] : "";
 }
 
-void CBinds::GetKey(const char *pBindStr, char *pBuf, size_t BufSize)
+const char *CBinds::Get(const CBindSlot &BindSlot) const
+{
+	return Get(BindSlot.m_Key, BindSlot.m_ModifierMask);
+}
+
+void CBinds::GetKey(const char *pBindStr, char *pBuf, size_t BufSize) const
 {
 	pBuf[0] = '\0';
-	for(int Modifier = MODIFIER_NONE; Modifier < MODIFIER_COMBINATION_COUNT; Modifier++)
+	for(int Modifier = KeyModifier::NONE; Modifier < KeyModifier::COMBINATION_COUNT; Modifier++)
 	{
 		for(int KeyId = KEY_FIRST; KeyId < KEY_LAST; KeyId++)
 		{
@@ -361,7 +366,7 @@ void CBinds::ConBinds(IConsole::IResult *pResult, void *pUserData)
 	}
 	else
 	{
-		for(int Modifier = MODIFIER_NONE; Modifier < MODIFIER_COMBINATION_COUNT; Modifier++)
+		for(int Modifier = KeyModifier::NONE; Modifier < KeyModifier::COMBINATION_COUNT; Modifier++)
 		{
 			for(int Key = KEY_FIRST; Key < KEY_LAST; Key++)
 			{
@@ -396,59 +401,58 @@ void CBinds::ConUnbindAll(IConsole::IResult *pResult, void *pUserData)
 	pBinds->UnbindAll();
 }
 
-CBinds::CBindSlot CBinds::GetBindSlot(const char *pBindString) const
+CBindSlot CBinds::GetBindSlot(const char *pBindString) const
 {
-	int ModifierMask = MODIFIER_NONE;
+	int ModifierMask = KeyModifier::NONE;
 	char aMod[32];
 	aMod[0] = '\0';
 	const char *pKey = str_next_token(pBindString, "+", aMod, sizeof(aMod));
 	while(aMod[0] && *(pKey))
 	{
 		if(!str_comp_nocase(aMod, "shift"))
-			ModifierMask |= (1 << MODIFIER_SHIFT);
+			ModifierMask |= (1 << KeyModifier::SHIFT);
 		else if(!str_comp_nocase(aMod, "ctrl"))
-			ModifierMask |= (1 << MODIFIER_CTRL);
+			ModifierMask |= (1 << KeyModifier::CTRL);
 		else if(!str_comp_nocase(aMod, "alt"))
-			ModifierMask |= (1 << MODIFIER_ALT);
+			ModifierMask |= (1 << KeyModifier::ALT);
 		else if(!str_comp_nocase(aMod, "gui"))
-			ModifierMask |= (1 << MODIFIER_GUI);
+			ModifierMask |= (1 << KeyModifier::GUI);
 		else
-			return {KEY_UNKNOWN, MODIFIER_NONE};
+			return EMPTY_BIND_SLOT;
 
 		if(str_find(pKey + 1, "+"))
 			pKey = str_next_token(pKey + 1, "+", aMod, sizeof(aMod));
 		else
 			break;
 	}
-	return {Input()->FindKeyByName(ModifierMask == MODIFIER_NONE ? aMod : pKey + 1), ModifierMask};
+	return {Input()->FindKeyByName(ModifierMask == KeyModifier::NONE ? aMod : pKey + 1), ModifierMask};
 }
 
 const char *CBinds::GetModifierName(int Modifier)
 {
 	switch(Modifier)
 	{
-	case MODIFIER_SHIFT:
+	case KeyModifier::SHIFT:
 		return "shift";
-	case MODIFIER_CTRL:
+	case KeyModifier::CTRL:
 		return "ctrl";
-	case MODIFIER_ALT:
+	case KeyModifier::ALT:
 		return "alt";
-	case MODIFIER_GUI:
+	case KeyModifier::GUI:
 		return "gui";
 	default:
-		dbg_assert(false, "Modifier invalid: %d", Modifier);
-		dbg_break();
+		dbg_assert_failed("Modifier invalid: %d", Modifier);
 	}
 }
 
 void CBinds::GetKeyBindName(int Key, int ModifierMask, char *pBuf, size_t BufSize) const
 {
 	pBuf[0] = '\0';
-	for(int k = 1; k < MODIFIER_COUNT; k++)
+	for(int Modifier = KeyModifier::CTRL; Modifier < KeyModifier::COUNT; Modifier++)
 	{
-		if(ModifierMask & (1 << k))
+		if(ModifierMask & (1 << Modifier))
 		{
-			str_append(pBuf, GetModifierName(k), BufSize);
+			str_append(pBuf, GetModifierName(Modifier), BufSize);
 			str_append(pBuf, "+", BufSize);
 		}
 	}
@@ -475,7 +479,7 @@ void CBinds::ConfigSaveCallback(IConfigManager *pConfigManager, void *pUserData)
 	CBinds *pSelf = (CBinds *)pUserData;
 
 	pConfigManager->WriteLine("unbindall");
-	for(int Modifier = MODIFIER_NONE; Modifier < MODIFIER_COMBINATION_COUNT; Modifier++)
+	for(int Modifier = KeyModifier::NONE; Modifier < KeyModifier::COMBINATION_COUNT; Modifier++)
 	{
 		for(int Key = KEY_FIRST; Key < KEY_LAST; Key++)
 		{
@@ -510,17 +514,22 @@ void CBinds::SetDDRaceBinds(bool FreeOnly)
 		Bind(KEY_X, "toggle cl_dummy 0 1", FreeOnly);
 		Bind(KEY_H, "toggle cl_dummy_hammer 0 1", FreeOnly);
 		Bind(KEY_SLASH, "+show_chat; chat all /", FreeOnly);
-		Bind(KEY_PAGEUP, "toggle cl_overlay_entities 0 100", FreeOnly);
 		Bind(KEY_KP_0, "say /emote normal 999999", FreeOnly);
 		Bind(KEY_KP_1, "say /emote happy 999999", FreeOnly);
 		Bind(KEY_KP_2, "say /emote angry 999999", FreeOnly);
 		Bind(KEY_KP_3, "say /emote pain 999999", FreeOnly);
 		Bind(KEY_KP_4, "say /emote surprise 999999", FreeOnly);
 		Bind(KEY_KP_5, "say /emote blink 999999", FreeOnly);
-		Bind(KEY_MOUSE_3, "+spectate", FreeOnly);
 		Bind(KEY_MINUS, "spectate_previous", FreeOnly);
 		Bind(KEY_EQUALS, "spectate_next", FreeOnly);
 	}
 
-	g_Config.m_ClDDRaceBindsSet = 1;
+	if(g_Config.m_ClDDRaceBindsSet < 2)
+	{
+		const bool DontModifySpectate = FreeOnly && str_comp(Get(KEY_MOUSE_3, KeyModifier::NONE), "+spectate") != 0;
+		Bind(KEY_MOUSE_3, "toggle_scoreboard_cursor; +spectate", DontModifySpectate);
+		Bind(KEY_LALT, "toggle_scoreboard_cursor", FreeOnly);
+	}
+
+	g_Config.m_ClDDRaceBindsSet = 2;
 }
