@@ -8,6 +8,7 @@
 
 #include <generated/protocol.h>
 
+#include <game/client/components/important_alert.h>
 #include <game/client/components/motd.h>
 #include <game/client/components/scoreboard.h>
 #include <game/client/gameclient.h>
@@ -35,8 +36,14 @@ void CBroadcast::OnRender()
 
 void CBroadcast::RenderServerBroadcast()
 {
-	if(GameClient()->m_Scoreboard.IsActive() || GameClient()->m_Motd.IsActive() || !g_Config.m_ClShowBroadcasts)
+	if(GameClient()->m_Scoreboard.IsActive() ||
+		GameClient()->m_Motd.IsActive() ||
+		GameClient()->m_ImportantAlert.IsActive() ||
+		!g_Config.m_ClShowBroadcasts)
+	{
 		return;
+	}
+
 	const float SecondsRemaining = (m_BroadcastTick - Client()->GameTick(g_Config.m_ClDummy)) / (float)Client()->GameTickSpeed();
 	if(SecondsRemaining <= 0.0f)
 	{
