@@ -5,8 +5,6 @@
 
 #include <engine/textrender.h>
 
-#include <generated/protocol.h>
-
 #include <game/client/component.h>
 
 class CBroadcast : public CComponent
@@ -18,7 +16,6 @@ class CBroadcast : public CComponent
 	STextContainerIndex m_TextContainerIndex;
 
 	void RenderServerBroadcast();
-	void OnBroadcastMessage(const CNetMsg_Sv_Broadcast *pMsg);
 
 public:
 	int Sizeof() const override { return sizeof(*this); }
