@@ -18,10 +18,19 @@ public:
 	float GetMinMouseDistance() const;
 	float GetMaxMouseDistance() const;
 
+	enum class EMouseInputType
+	{
+		ABSOLUTE,
+		RELATIVE,
+		AUTOMATED,
+	};
+
 	vec2 m_aMousePos[NUM_DUMMIES];
 	vec2 m_aMousePosOnAction[NUM_DUMMIES];
 	vec2 m_aTargetPos[NUM_DUMMIES];
 
+	EMouseInputType m_aMouseInputType[NUM_DUMMIES];
+
 	int m_aAmmoCount[NUM_WEAPONS];
 
 	int64_t m_LastSendTime;
