@@ -2,10 +2,10 @@
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
 #include "countryflags.h"
 
+#include <base/log.h>
 #include <base/math.h>
 #include <base/system.h>
 
-#include <engine/console.h>
 #include <engine/graphics.h>
 #include <engine/shared/config.h>
 #include <engine/shared/linereader.h>
@@ -17,9 +17,7 @@ void CCountryFlags::LoadCountryflagsIndexfile()
 	CLineReader LineReader;
 	if(!LineReader.OpenFile(Storage()->OpenFile(pFilename, IOFLAG_READ, IStorage::TYPE_ALL)))
 	{
-		char aBuf[128];
-		str_format(aBuf, sizeof(aBuf), "couldn't open index file '%s'", pFilename);
-		Console()->Print(IConsole::OUTPUT_LEVEL_ADDINFO, "countryflags", aBuf);
+		log_error("countryflags", "couldn't open index file '%s'", pFilename);
 		return;
 	}
 
@@ -33,24 +31,20 @@ void CCountryFlags::LoadCountryflagsIndexfile()
 		const char *pReplacement = LineReader.Get();
 		if(!pReplacement)
 		{
-			Console()->Print(IConsole::OUTPUT_LEVEL_ADDINFO, "countryflags", "unexpected end of index file");
+			log_error("countryflags", "unexpected end of index file");
 			break;
 		}
 
 		if(pReplacement[0] != '=' || pReplacement[1] != '=' || pReplacement[2] != ' ')
 		{
-			char aBuf[128];
-			str_format(aBuf, sizeof(aBuf), "malform replacement for index '%s'", aOrigin);
-			Console()->Print(IConsole::OUTPUT_LEVEL_ADDINFO, "countryflags", aBuf);
+			log_error("countryflags", "malformed replacement for index '%s'", aOrigin);
 			continue;
 		}
 
 		int CountryCode = str_toint(pReplacement + 3);
 		if(CountryCode < CODE_LB || CountryCode > CODE_UB)
 		{
-			char aBuf[128];
-			str_format(aBuf, sizeof(aBuf), "country code '%i' not within valid code range [%i..%i]", CountryCode, CODE_LB, CODE_UB);
-			Console()->Print(IConsole::OUTPUT_LEVEL_ADDINFO, "countryflags", aBuf);
+			log_error("countryflags", "country code '%i' not within valid code range [%i..%i]", CountryCode, CODE_LB, CODE_UB);
 			continue;
 		}
 
@@ -60,9 +54,7 @@ void CCountryFlags::LoadCountryflagsIndexfile()
 		str_format(aBuf, sizeof(aBuf), "countryflags/%s.png", aOrigin);
 		if(!Graphics()->LoadPng(Info, aBuf, IStorage::TYPE_ALL))
 		{
-			char aMsg[128];
-			str_format(aMsg, sizeof(aMsg), "failed to load '%s'", aBuf);
-			Console()->Print(IConsole::OUTPUT_LEVEL_ADDINFO, "countryflags", aMsg);
+			log_error("countryflags", "failed to load '%s'", aBuf);
 			continue;
 		}
 
@@ -74,8 +66,7 @@ void CCountryFlags::LoadCountryflagsIndexfile()
 
 		if(g_Config.m_Debug)
 		{
-			str_format(aBuf, sizeof(aBuf), "loaded country flag '%s'", aOrigin);
-			Console()->Print(IConsole::OUTPUT_LEVEL_ADDINFO, "countryflags", aBuf);
+			log_debug("countryflags", "loaded country flag '%s'", aOrigin);
 		}
 		m_vCountryFlags.push_back(CountryFlag);
 	}
@@ -92,11 +83,7 @@ void CCountryFlags::LoadCountryflagsIndexfile()
 		}
 
 	// init LUT
-	if(DefaultIndex != 0)
-		for(size_t &CodeIndexLUT : m_aCodeIndexLUT)
-			CodeIndexLUT = DefaultIndex;
-	else
-		mem_zero(m_aCodeIndexLUT, sizeof(m_aCodeIndexLUT));
+	std::fill(std::begin(m_aCodeIndexLUT), std::end(m_aCodeIndexLUT), DefaultIndex);
 	for(size_t i = 0; i < m_vCountryFlags.size(); ++i)
 		m_aCodeIndexLUT[maximum(0, (m_vCountryFlags[i].m_CountryCode - CODE_LB) % CODE_RANGE)] = i;
 }
@@ -108,7 +95,7 @@ void CCountryFlags::OnInit()
 	LoadCountryflagsIndexfile();
 	if(m_vCountryFlags.empty())
 	{
-		Console()->Print(IConsole::OUTPUT_LEVEL_STANDARD, "countryflags", "failed to load country flags. folder='countryflags/'");
+		log_error("countryflags", "failed to load country flags. folder='countryflags/'");
 		CCountryFlag DummyEntry;
 		DummyEntry.m_CountryCode = -1;
 		DummyEntry.m_aCountryCodeString[0] = '\0';
@@ -116,9 +103,9 @@ void CCountryFlags::OnInit()
 	}
 
 	m_FlagsQuadContainerIndex = Graphics()->CreateQuadContainer(false);
-	Graphics()->SetColor(1.f, 1.f, 1.f, 1.f);
-	Graphics()->QuadsSetSubset(0, 0, 1, 1);
-	Graphics()->QuadContainerAddSprite(m_FlagsQuadContainerIndex, 0, 0, 1, 1);
+	Graphics()->SetColor(1.0f, 1.0f, 1.0f, 1.0f);
+	Graphics()->QuadsSetSubset(0.0f, 0.0f, 1.0f, 1.0f);
+	Graphics()->QuadContainerAddSprite(m_FlagsQuadContainerIndex, 0.0f, 0.0f, 1.0f, 1.0f);
 	Graphics()->QuadContainerUpload(m_FlagsQuadContainerIndex);
 }
 
@@ -127,21 +114,21 @@ size_t CCountryFlags::Num() const
 	return m_vCountryFlags.size();
 }
 
-const CCountryFlags::CCountryFlag *CCountryFlags::GetByCountryCode(int CountryCode) const
+const CCountryFlags::CCountryFlag &CCountryFlags::GetByCountryCode(int CountryCode) const
 {
 	return GetByIndex(m_aCodeIndexLUT[maximum(0, (CountryCode - CODE_LB) % CODE_RANGE)]);
 }
 
-const CCountryFlags::CCountryFlag *CCountryFlags::GetByIndex(size_t Index) const
+const CCountryFlags::CCountryFlag &CCountryFlags::GetByIndex(size_t Index) const
 {
-	return &m_vCountryFlags[Index % m_vCountryFlags.size()];
+	return m_vCountryFlags[Index % m_vCountryFlags.size()];
 }
 
-void CCountryFlags::Render(const CCountryFlag *pFlag, ColorRGBA Color, float x, float y, float w, float h)
+void CCountryFlags::Render(const CCountryFlag &Flag, ColorRGBA Color, float x, float y, float w, float h)
 {
-	if(pFlag->m_Texture.IsValid())
+	if(Flag.m_Texture.IsValid())
 	{
-		Graphics()->TextureSet(pFlag->m_Texture);
+		Graphics()->TextureSet(Flag.m_Texture);
 		Graphics()->SetColor(Color);
 		Graphics()->QuadsSetRotation(0.0f);
 		Graphics()->RenderQuadContainerEx(m_FlagsQuadContainerIndex, 0, -1, x, y, w, h);
