@@ -213,18 +213,49 @@ void CPlayers::RenderHookCollLine(
 
 	const int MaxHookTicks = 5 * Client()->GameTickSpeed(); // calculating above 5 seconds is very expensive and unlikely to happen
 
+	auto AddHookPlayerSegment = [&](const vec2 &StartPos, const vec2 &EndPos, const vec2 &HookablePlayerPosition, const vec2 &HitPos) {
+		HookCollColor = color_cast<ColorRGBA>(ColorHSLA(g_Config.m_ClHookCollColorTeeColl));
+
+		// stop hookline at player circle so it looks better
+		vec2 aIntersections[2];
+		int NumIntersections = intersect_line_circle(StartPos, EndPos, HookablePlayerPosition, CCharacterCore::PhysicalSize() * 1.45f / 2.0f, aIntersections);
+		if(NumIntersections == 2)
+		{
+			if(distance(Position, aIntersections[0]) < distance(Position, aIntersections[1]))
+				vLineSegments.emplace_back(StartPos, aIntersections[0]);
+			else
+				vLineSegments.emplace_back(StartPos, aIntersections[1]);
+		}
+		else if(NumIntersections == 1)
+			vLineSegments.emplace_back(StartPos, aIntersections[0]);
+		else
+			vLineSegments.emplace_back(StartPos, HitPos);
+	};
+
 	// simulate the hook into the future
 	int HookTick;
+	bool HookEnteredTelehook = false;
 	for(HookTick = 0; HookTick < MaxHookTicks; ++HookTick)
 	{
 		int Tele;
-		vec2 HitPos;
+		vec2 HitPos, IntersectedPlayerPosition;
 		vec2 SegmentEndPos = SegmentStartPos + QuantizedDirection * HookFireSpeed;
 
 		// check if a hook would enter retracting state in this tick
 		if(distance(BasePos, SegmentEndPos) > HookLength)
 		{
-			// the line is too long here, and the hook starts to retract, use old position
+			// check if the retracting hook hits a player
+			if(!HookEnteredTelehook)
+			{
+				vec2 RetractingHookEndPos = BasePos + normalize(SegmentEndPos - BasePos) * HookLength;
+				if(GameClient()->IntersectCharacter(SegmentStartPos, RetractingHookEndPos, HitPos, ClientId, &IntersectedPlayerPosition) != -1)
+				{
+					AddHookPlayerSegment(LineStartPos, SegmentEndPos, IntersectedPlayerPosition, HitPos);
+					break;
+				}
+			}
+
+			// the line is too long here, and the hook retracts, use old position
 			vLineSegments.emplace_back(LineStartPos, SegmentStartPos);
 			break;
 		}
@@ -233,10 +264,9 @@ void CPlayers::RenderHookCollLine(
 		int Hit = Collision()->IntersectLineTeleHook(SegmentStartPos, SegmentEndPos, &HitPos, nullptr, &Tele);
 
 		// check if we intersect a player
-		if(GameClient()->IntersectCharacter(SegmentStartPos, HitPos, SegmentEndPos, ClientId) != -1)
+		if(GameClient()->IntersectCharacter(SegmentStartPos, HitPos, SegmentEndPos, ClientId, &IntersectedPlayerPosition) != -1)
 		{
-			HookCollColor = color_cast<ColorRGBA>(ColorHSLA(g_Config.m_ClHookCollColorTeeColl));
-			vLineSegments.emplace_back(LineStartPos, SegmentEndPos);
+			AddHookPlayerSegment(LineStartPos, HitPos, IntersectedPlayerPosition, SegmentEndPos);
 			break;
 		}
 
@@ -267,6 +297,7 @@ void CPlayers::RenderHookCollLine(
 
 		// we are hitting TILE_TELEINHOOK
 		vLineSegments.emplace_back(LineStartPos, HitPos);
+		HookEnteredTelehook = true;
 
 		// check tele outs
 		const std::vector<vec2> &vTeleOuts = Collision()->TeleOuts(Tele - 1);
@@ -456,6 +487,8 @@ void CPlayers::RenderPlayer(
 	float Alpha = (OtherTeam || ClientId < 0) ? g_Config.m_ClShowOthersAlpha / 100.0f : 1.0f;
 	if(ClientId == -2) // ghost
 		Alpha = g_Config.m_ClRaceGhostAlpha / 100.0f;
+	// TODO: snd_game_volume_others
+	const float Volume = 1.0f;
 
 	// set size
 	RenderInfo.m_Size = 64.0f;
@@ -544,7 +577,7 @@ void CPlayers::RenderPlayer(
 
 	// do skidding
 	if(!InAir && WantOtherDir && length(Vel * 50) > 500.0f)
-		GameClient()->m_Effects.SkidTrail(Position, Vel, Player.m_Direction, Alpha);
+		GameClient()->m_Effects.SkidTrail(Position, Vel, Player.m_Direction, Alpha, Volume);
 
 	// draw gun
 	if(Player.m_Weapon >= 0)
