@@ -50,11 +50,7 @@ bool CLaser::HitCharacter(vec2 From, vec2 To)
 	m_Energy = -1;
 	if(m_Type == WEAPON_SHOTGUN)
 	{
-		float Strength;
-		if(!m_TuneZone)
-			Strength = Tuning()->m_ShotgunStrength;
-		else
-			Strength = TuningList()[m_TuneZone].m_ShotgunStrength;
+		float Strength = TuningList()[m_TuneZone].m_ShotgunStrength;
 
 		const vec2 &HitPos = pHit->Core()->m_Pos;
 		if(!g_Config.m_SvOldLaser)
