@@ -17,7 +17,7 @@ public:
 	CPickup(CGameWorld *pGameWorld, int Id, const CPickupData *pPickup);
 	void FillInfo(CNetObj_Pickup *pPickup);
 	bool Match(CPickup *pPickup);
-	bool InDDNetTile() { return m_IsCoreActive; }
+	bool InDDNetTile() const { return m_IsCoreActive; }
 
 	int Type() const { return m_Type; }
 	int Subtype() const { return m_Subtype; }
