@@ -32,7 +32,7 @@ public:
 
 	std::vector<SSwitchers> &Switchers() { return m_pGameWorld->Switchers(); }
 	CGameWorld *GameWorld() { return m_pGameWorld; }
-	CTuningParams *Tuning() { return GameWorld()->Tuning(); }
+	CTuningParams *GlobalTuning() { return &GameWorld()->TuningList()[0]; }
 	CTuningParams *TuningList() { return GameWorld()->TuningList(); }
 	CTuningParams *GetTuning(int i) { return GameWorld()->GetTuning(i); }
 	class CCollision *Collision() { return GameWorld()->Collision(); }
