@@ -50,6 +50,13 @@ CGameWorld::~CGameWorld()
 		m_pParent->m_pChild = nullptr;
 }
 
+void CGameWorld::Init(CCollision *pCollision, CTuningParams *pTuningList, const CMapBugs *pMapBugs)
+{
+	m_pCollision = pCollision;
+	m_pTuningList = pTuningList;
+	m_pMapBugs = pMapBugs;
+}
+
 CEntity *CGameWorld::FindFirst(int Type)
 {
 	return Type < 0 || Type >= NUM_ENTTYPES ? nullptr : m_apFirstEntityTypes[Type];
@@ -326,11 +333,6 @@ void CGameWorld::ReleaseHooked(int ClientId)
 	}
 }
 
-CTuningParams *CGameWorld::Tuning()
-{
-	return &m_Core.m_aTuning[g_Config.m_ClDummy];
-}
-
 CEntity *CGameWorld::GetEntity(int Id, int EntityType)
 {
 	for(CEntity *pEnt = m_apFirstEntityTypes[EntityType]; pEnt; pEnt = pEnt->m_pNextTypeEntity)
@@ -360,9 +362,9 @@ void CGameWorld::CreateExplosion(vec2 Pos, int Owner, int Weapon, bool NoDamage,
 		l = 1 - std::clamp((l - InnerRadius) / (Radius - InnerRadius), 0.0f, 1.0f);
 		float Strength;
 		if(Owner == -1 || !GetCharacterById(Owner))
-			Strength = Tuning()->m_ExplosionStrength;
+			Strength = GlobalTuning()->m_ExplosionStrength;
 		else
-			Strength = GetCharacterById(Owner)->Tuning()->m_ExplosionStrength;
+			Strength = GetCharacterById(Owner)->GetTuning(GetCharacterById(Owner)->GetOverriddenTuneZone())->m_ExplosionStrength;
 
 		float Dmg = Strength * l;
 		if((int)Dmg)
@@ -631,10 +633,6 @@ void CGameWorld::CopyWorld(CGameWorld *pFrom)
 	m_GameTick = pFrom->m_GameTick;
 	m_pCollision = pFrom->m_pCollision;
 	m_WorldConfig = pFrom->m_WorldConfig;
-	for(int i = 0; i < 2; i++)
-	{
-		m_Core.m_aTuning[i] = pFrom->m_Core.m_aTuning[i];
-	}
 	m_pTuningList = pFrom->m_pTuningList;
 	m_pMapBugs = pFrom->m_pMapBugs;
 	m_Teams = pFrom->m_Teams;
