@@ -248,7 +248,7 @@ public:
 		const std::shared_ptr<IMapSetting> &Setting() const { return m_pCurrentSetting; }
 		CLineInput *LineInput() const { return m_pLineInput; }
 		void SetFontSize(float FontSize) { m_FontSize = FontSize; }
-		int CommentOffset() const { return m_CommentOffset; };
+		int CommentOffset() const { return m_CommentOffset; }
 
 		int CheckCollision(ECollisionCheckResult &Result) const;
 		int CheckCollision(const std::vector<CEditorMapSetting> &vSettings, ECollisionCheckResult &Result) const;
@@ -330,7 +330,7 @@ private:
 	//   CCommandArgumentConstraintBuilder Command(&m_Container);
 	//   Command("tune", 2).Unique(0); // Defines argument 0 of command "tune" having 2 args as UNIQUE
 	//   Command("tune_zone", 3).Multiple(0).Unique(1);
-	//   // ^ Multiple() currently is only for readable purposes. It can be omited:
+	//   // ^ Multiple() currently is only for readable purposes. It can be omitted:
 	//   // Command("tune_zone", 3).Unique(1);
 	//
 
@@ -342,7 +342,7 @@ private:
 
 	private:
 		CArgumentConstraintsBuilder(TArgumentConstraints *pContainer) :
-			m_pContainer(pContainer){};
+			m_pContainer(pContainer) {}
 
 		TArgumentConstraints *m_pContainer;
 
