@@ -1,7 +1,7 @@
 #include <game/editor/editor.h>
 
-CLayerFront::CLayerFront(CEditor *pEditor, int w, int h) :
-	CLayerTiles(pEditor, w, h)
+CLayerFront::CLayerFront(CEditorMap *pMap, int w, int h) :
+	CLayerTiles(pMap, w, h)
 {
 	str_copy(m_aName, "Front");
 	m_HasFront = true;
@@ -11,13 +11,13 @@ void CLayerFront::SetTile(int x, int y, CTile Tile)
 {
 	if(Tile.m_Index == TILE_THROUGH_CUT)
 	{
-		m_pEditor->m_Map.m_pGameLayer->CLayerTiles::SetTile(x, y, CTile{TILE_NOHOOK}); // NOLINT(bugprone-parent-virtual-call)
+		Map()->m_pGameLayer->CLayerTiles::SetTile(x, y, CTile{TILE_NOHOOK}); // NOLINT(bugprone-parent-virtual-call)
 	}
 	else if(Tile.m_Index == TILE_AIR && CLayerTiles::GetTile(x, y).m_Index == TILE_THROUGH_CUT)
 	{
-		m_pEditor->m_Map.m_pGameLayer->CLayerTiles::SetTile(x, y, CTile{TILE_AIR}); // NOLINT(bugprone-parent-virtual-call)
+		Map()->m_pGameLayer->CLayerTiles::SetTile(x, y, CTile{TILE_AIR}); // NOLINT(bugprone-parent-virtual-call)
 	}
-	if(m_pEditor->IsAllowPlaceUnusedTiles() || IsValidFrontTile(Tile.m_Index))
+	if(Editor()->IsAllowPlaceUnusedTiles() || IsValidFrontTile(Tile.m_Index))
 	{
 		CLayerTiles::SetTile(x, y, Tile);
 	}
@@ -34,8 +34,8 @@ void CLayerFront::Resize(int NewW, int NewH)
 	CLayerTiles::Resize(NewW, NewH);
 
 	// resize gamelayer too
-	if(m_pEditor->m_Map.m_pGameLayer->m_Width != NewW || m_pEditor->m_Map.m_pGameLayer->m_Height != NewH)
-		m_pEditor->m_Map.m_pGameLayer->Resize(NewW, NewH);
+	if(Map()->m_pGameLayer->m_Width != NewW || Map()->m_pGameLayer->m_Height != NewH)
+		Map()->m_pGameLayer->Resize(NewW, NewH);
 }
 
 bool CLayerFront::IsEmpty() const
@@ -49,7 +49,7 @@ bool CLayerFront::IsEmpty() const
 			{
 				continue;
 			}
-			if(m_pEditor->IsAllowPlaceUnusedTiles() || IsValidFrontTile(Index))
+			if(Editor()->IsAllowPlaceUnusedTiles() || IsValidFrontTile(Index))
 			{
 				return false;
 			}
