@@ -6,7 +6,7 @@
 class CLayerFront : public CLayerTiles
 {
 public:
-	CLayerFront(CEditor *pEditor, int w, int h);
+	CLayerFront(CEditorMap *pMap, int w, int h);
 
 	void SetTile(int x, int y, CTile Tile) override;
 	void Resize(int NewW, int NewH) override;
