@@ -7,10 +7,9 @@
 
 static const float s_SourceVisualSize = 32.0f;
 
-CLayerSounds::CLayerSounds(CEditor *pEditor) :
-	CLayer(pEditor)
+CLayerSounds::CLayerSounds(CEditorMap *pMap) :
+	CLayer(pMap, LAYERTYPE_SOUNDS)
 {
-	m_Type = LAYERTYPE_SOUNDS;
 	m_aName[0] = '\0';
 	m_Sound = -1;
 }
@@ -36,7 +35,7 @@ void CLayerSounds::Render(bool Tileset)
 	for(const auto &Source : m_vSources)
 	{
 		ColorRGBA Offset = ColorRGBA(0.0f, 0.0f, 0.0f, 0.0f);
-		m_pEditor->EnvelopeEval(Source.m_PosEnvOffset, Source.m_PosEnv, Offset, 2);
+		Editor()->EnvelopeEval(Source.m_PosEnvOffset, Source.m_PosEnv, Offset, 2);
 		const vec2 Position = vec2(fx2f(Source.m_Position.x) + Offset.r, fx2f(Source.m_Position.y) + Offset.g);
 		const float Falloff = Source.m_Falloff / 255.0f;
 
@@ -44,10 +43,10 @@ void CLayerSounds::Render(bool Tileset)
 		{
 		case CSoundShape::SHAPE_CIRCLE:
 		{
-			m_pEditor->Graphics()->DrawCircle(Position.x, Position.y, Source.m_Shape.m_Circle.m_Radius, 32);
+			Graphics()->DrawCircle(Position.x, Position.y, Source.m_Shape.m_Circle.m_Radius, 32);
 			if(Falloff > 0.0f)
 			{
-				m_pEditor->Graphics()->DrawCircle(Position.x, Position.y, Source.m_Shape.m_Circle.m_Radius * Falloff, 32);
+				Graphics()->DrawCircle(Position.x, Position.y, Source.m_Shape.m_Circle.m_Radius * Falloff, 32);
 			}
 			break;
 		}
@@ -55,10 +54,10 @@ void CLayerSounds::Render(bool Tileset)
 		{
 			const float Width = fx2f(Source.m_Shape.m_Rectangle.m_Width);
 			const float Height = fx2f(Source.m_Shape.m_Rectangle.m_Height);
-			m_pEditor->Graphics()->DrawRectExt(Position.x - Width / 2, Position.y - Height / 2, Width, Height, 0.0f, IGraphics::CORNER_NONE);
+			Graphics()->DrawRectExt(Position.x - Width / 2, Position.y - Height / 2, Width, Height, 0.0f, IGraphics::CORNER_NONE);
 			if(Falloff > 0.0f)
 			{
-				m_pEditor->Graphics()->DrawRectExt(Position.x - Falloff * Width / 2, Position.y - Falloff * Height / 2, Width * Falloff, Height * Falloff, 0.0f, IGraphics::CORNER_NONE);
+				Graphics()->DrawRectExt(Position.x - Falloff * Width / 2, Position.y - Falloff * Height / 2, Width * Falloff, Height * Falloff, 0.0f, IGraphics::CORNER_NONE);
 			}
 			break;
 		}
@@ -72,13 +71,13 @@ void CLayerSounds::Render(bool Tileset)
 	Graphics()->QuadsBegin();
 
 	Graphics()->SetColor(1.0f, 1.0f, 1.0f, 1.0f);
-	m_pEditor->Graphics()->SelectSprite(SPRITE_AUDIO_SOURCE);
+	Graphics()->SelectSprite(SPRITE_AUDIO_SOURCE);
 	for(const auto &Source : m_vSources)
 	{
 		ColorRGBA Offset = ColorRGBA(0.0f, 0.0f, 0.0f, 0.0f);
-		m_pEditor->EnvelopeEval(Source.m_PosEnvOffset, Source.m_PosEnv, Offset, 2);
+		Editor()->EnvelopeEval(Source.m_PosEnvOffset, Source.m_PosEnv, Offset, 2);
 		const vec2 Position = vec2(fx2f(Source.m_Position.x) + Offset.r, fx2f(Source.m_Position.y) + Offset.g);
-		m_pEditor->Graphics()->DrawSprite(Position.x, Position.y, m_pEditor->MapView()->ScaleLength(s_SourceVisualSize));
+		Graphics()->DrawSprite(Position.x, Position.y, Editor()->MapView()->ScaleLength(s_SourceVisualSize));
 	}
 
 	Graphics()->QuadsEnd();
@@ -86,7 +85,7 @@ void CLayerSounds::Render(bool Tileset)
 
 CSoundSource *CLayerSounds::NewSource(int x, int y)
 {
-	m_pEditor->m_Map.OnModify();
+	Map()->OnModify();
 
 	m_vSources.emplace_back();
 	CSoundSource *pSource = &m_vSources[m_vSources.size() - 1];
@@ -119,7 +118,7 @@ void CLayerSounds::BrushSelecting(CUIRect Rect)
 int CLayerSounds::BrushGrab(CLayerGroup *pBrush, CUIRect Rect)
 {
 	// create new layer
-	std::shared_ptr<CLayerSounds> pGrabbed = std::make_shared<CLayerSounds>(m_pEditor);
+	std::shared_ptr<CLayerSounds> pGrabbed = std::make_shared<CLayerSounds>(pBrush->Map());
 	pGrabbed->m_Sound = m_Sound;
 	pBrush->AddLayer(pGrabbed);
 
@@ -154,8 +153,8 @@ void CLayerSounds::BrushPlace(CLayer *pBrush, vec2 WorldPos)
 		m_vSources.push_back(NewSource);
 		vAddedSources.push_back(NewSource);
 	}
-	m_pEditor->m_EditorHistory.RecordAction(std::make_shared<CEditorActionSoundPlace>(m_pEditor, m_pEditor->m_SelectedGroup, m_pEditor->m_vSelectedLayers[0], vAddedSources));
-	m_pEditor->m_Map.OnModify();
+	Map()->m_EditorHistory.RecordAction(std::make_shared<CEditorActionSoundPlace>(Map(), Editor()->m_SelectedGroup, Editor()->m_vSelectedLayers[0], vAddedSources));
+	Map()->OnModify();
 }
 
 CUi::EPopupMenuFunctionResult CLayerSounds::RenderProperties(CUIRect *pToolBox)
@@ -167,24 +166,23 @@ CUi::EPopupMenuFunctionResult CLayerSounds::RenderProperties(CUIRect *pToolBox)
 
 	static int s_aIds[(int)ELayerSoundsProp::NUM_PROPS] = {0};
 	int NewVal = 0;
-	auto [State, Prop] = m_pEditor->DoPropertiesWithState<ELayerSoundsProp>(pToolBox, aProps, s_aIds, &NewVal);
+	auto [State, Prop] = Editor()->DoPropertiesWithState<ELayerSoundsProp>(pToolBox, aProps, s_aIds, &NewVal);
 	if(Prop != ELayerSoundsProp::PROP_NONE && (State == EEditState::END || State == EEditState::ONE_GO))
 	{
-		m_pEditor->m_Map.OnModify();
+		Map()->OnModify();
 	}
 
-	static CLayerSoundsPropTracker s_Tracker(m_pEditor);
-	s_Tracker.Begin(this, Prop, State);
+	Map()->m_LayerSoundsPropTracker.Begin(this, Prop, State);
 
 	if(Prop == ELayerSoundsProp::PROP_SOUND)
 	{
 		if(NewVal >= 0)
-			m_Sound = NewVal % m_pEditor->m_Map.m_vpSounds.size();
+			m_Sound = NewVal % Map()->m_vpSounds.size();
 		else
 			m_Sound = -1;
 	}
 
-	s_Tracker.End(Prop, State);
+	Map()->m_LayerSoundsPropTracker.End(Prop, State);
 
 	return CUi::POPUP_KEEP_OPEN;
 }
