@@ -17,13 +17,13 @@ struct STeleTileStateChange
 class CLayerTele : public CLayerTiles
 {
 public:
-	CLayerTele(CEditor *pEditor, int w, int h);
+	CLayerTele(CEditorMap *pMap, int w, int h);
 	CLayerTele(const CLayerTele &Other);
 	~CLayerTele() override;
 
 	CTeleTile *m_pTeleTile;
-	unsigned char m_TeleNum;
-	unsigned char m_TeleCheckpointNum;
+	unsigned char m_TeleNumber;
+	unsigned char m_TeleCheckpointNumber;
 
 	void Resize(int NewW, int NewH) override;
 	void Shift(EShiftDirection Direction) override;
