@@ -3,9 +3,9 @@
 
 #include <engine/client.h>
 #include <engine/console.h>
+#include <engine/engine.h>
 #include <engine/gfx/image_manipulation.h>
 #include <engine/graphics.h>
-#include <engine/serverbrowser.h>
 #include <engine/shared/datafile.h>
 #include <engine/sound.h>
 #include <engine/storage.h>
@@ -33,20 +33,20 @@ void CDataFileWriterFinishJob::Run()
 	m_Writer.Finish();
 }
 
-CDataFileWriterFinishJob::CDataFileWriterFinishJob(const char *pRealFileName, const char *pTempFileName, CDataFileWriter &&Writer) :
+CDataFileWriterFinishJob::CDataFileWriterFinishJob(const char *pRealFilename, const char *pTempFilename, CDataFileWriter &&Writer) :
 	m_Writer(std::move(Writer))
 {
-	str_copy(m_aRealFileName, pRealFileName);
-	str_copy(m_aTempFileName, pTempFileName);
+	str_copy(m_aRealFilename, pRealFilename);
+	str_copy(m_aTempFilename, pTempFilename);
 }
 
-bool CEditorMap::Save(const char *pFileName, const std::function<void(const char *pErrorMessage)> &ErrorHandler)
+bool CEditorMap::Save(const char *pFilename, const FErrorHandler &ErrorHandler)
 {
-	char aFileNameTmp[IO_MAX_PATH_LENGTH];
-	IStorage::FormatTmpPath(aFileNameTmp, sizeof(aFileNameTmp), pFileName);
+	char aFilenameTmp[IO_MAX_PATH_LENGTH];
+	IStorage::FormatTmpPath(aFilenameTmp, sizeof(aFilenameTmp), pFilename);
 
 	char aBuf[IO_MAX_PATH_LENGTH + 64];
-	str_format(aBuf, sizeof(aBuf), "saving to '%s'...", aFileNameTmp);
+	str_format(aBuf, sizeof(aBuf), "saving to '%s'...", aFilenameTmp);
 	m_pEditor->Console()->Print(IConsole::OUTPUT_LEVEL_STANDARD, "editor", aBuf);
 
 	if(!PerformPreSaveSanityChecks(ErrorHandler))
@@ -55,9 +55,9 @@ bool CEditorMap::Save(const char *pFileName, const std::function<void(const char
 	}
 
 	CDataFileWriter Writer;
-	if(!Writer.Open(m_pEditor->Storage(), aFileNameTmp))
+	if(!Writer.Open(m_pEditor->Storage(), aFilenameTmp))
 	{
-		str_format(aBuf, sizeof(aBuf), "Error: Failed to open file '%s' for writing.", aFileNameTmp);
+		str_format(aBuf, sizeof(aBuf), "Error: Failed to open file '%s' for writing.", aFilenameTmp);
 		ErrorHandler(aBuf);
 		return false;
 	}
@@ -407,14 +407,14 @@ bool CEditorMap::Save(const char *pFileName, const std::function<void(const char
 	}
 
 	// finish the data file
-	std::shared_ptr<CDataFileWriterFinishJob> pWriterFinishJob = std::make_shared<CDataFileWriterFinishJob>(pFileName, aFileNameTmp, std::move(Writer));
+	std::shared_ptr<CDataFileWriterFinishJob> pWriterFinishJob = std::make_shared<CDataFileWriterFinishJob>(pFilename, aFilenameTmp, std::move(Writer));
 	m_pEditor->Engine()->AddJob(pWriterFinishJob);
 	m_pEditor->m_WriterFinishJobs.push_back(pWriterFinishJob);
 
 	return true;
 }
 
-bool CEditorMap::PerformPreSaveSanityChecks(const std::function<void(const char *pErrorMessage)> &ErrorHandler)
+bool CEditorMap::PerformPreSaveSanityChecks(const FErrorHandler &ErrorHandler)
 {
 	bool Success = true;
 	char aErrorMessage[256];
@@ -442,10 +442,10 @@ bool CEditorMap::PerformPreSaveSanityChecks(const std::function<void(const char
 	return Success;
 }
 
-bool CEditorMap::Load(const char *pFileName, int StorageType, const std::function<void(const char *pErrorMessage)> &ErrorHandler)
+bool CEditorMap::Load(const char *pFilename, int StorageType, const FErrorHandler &ErrorHandler)
 {
 	CDataFileReader DataFile;
-	if(!DataFile.Open(m_pEditor->Storage(), pFileName, StorageType))
+	if(!DataFile.Open(m_pEditor->Storage(), pFilename, StorageType))
 	{
 		ErrorHandler("Error: Failed to open map file. See local console for details.");
 		return false;
@@ -520,7 +520,7 @@ bool CEditorMap::Load(const char *pFileName, int StorageType, const std::functio
 			CMapItemImage_v2 *pItem = (CMapItemImage_v2 *)DataFile.GetItem(Start + i);
 
 			// copy base info
-			std::shared_ptr<CEditorImage> pImg = std::make_shared<CEditorImage>(m_pEditor);
+			std::shared_ptr<CEditorImage> pImg = std::make_shared<CEditorImage>(this);
 			pImg->m_External = pItem->m_External;
 
 			const char *pName = DataFile.GetDataString(pItem->m_ImageName);
@@ -604,7 +604,7 @@ bool CEditorMap::Load(const char *pFileName, int StorageType, const std::functio
 			CMapItemSound *pItem = (CMapItemSound *)DataFile.GetItem(Start + i);
 
 			// copy base info
-			std::shared_ptr<CEditorSound> pSound = std::make_shared<CEditorSound>(m_pEditor);
+			std::shared_ptr<CEditorSound> pSound = std::make_shared<CEditorSound>(this);
 
 			const char *pName = DataFile.GetDataString(pItem->m_SoundName);
 			if(pName == nullptr || pName[0] == '\0')
@@ -696,7 +696,7 @@ bool CEditorMap::Load(const char *pFileName, int StorageType, const std::functio
 					std::shared_ptr<CLayerTiles> pTiles;
 					if(pTilemapItem->m_Flags & TILESLAYERFLAG_GAME)
 					{
-						pTiles = std::make_shared<CLayerGame>(m_pEditor, pTilemapItem->m_Width, pTilemapItem->m_Height);
+						pTiles = std::make_shared<CLayerGame>(this, pTilemapItem->m_Width, pTilemapItem->m_Height);
 						MakeGameLayer(pTiles);
 						MakeGameGroup(pGroup);
 					}
@@ -705,7 +705,7 @@ bool CEditorMap::Load(const char *pFileName, int StorageType, const std::functio
 						if(pTilemapItem->m_Version <= 2)
 							pTilemapItem->m_Tele = *((const int *)(pTilemapItem) + 15);
 
-						pTiles = std::make_shared<CLayerTele>(m_pEditor, pTilemapItem->m_Width, pTilemapItem->m_Height);
+						pTiles = std::make_shared<CLayerTele>(this, pTilemapItem->m_Width, pTilemapItem->m_Height);
 						MakeTeleLayer(pTiles);
 					}
 					else if(pTilemapItem->m_Flags & TILESLAYERFLAG_SPEEDUP)
@@ -713,7 +713,7 @@ bool CEditorMap::Load(const char *pFileName, int StorageType, const std::functio
 						if(pTilemapItem->m_Version <= 2)
 							pTilemapItem->m_Speedup = *((const int *)(pTilemapItem) + 16);
 
-						pTiles = std::make_shared<CLayerSpeedup>(m_pEditor, pTilemapItem->m_Width, pTilemapItem->m_Height);
+						pTiles = std::make_shared<CLayerSpeedup>(this, pTilemapItem->m_Width, pTilemapItem->m_Height);
 						MakeSpeedupLayer(pTiles);
 					}
 					else if(pTilemapItem->m_Flags & TILESLAYERFLAG_FRONT)
@@ -721,7 +721,7 @@ bool CEditorMap::Load(const char *pFileName, int StorageType, const std::functio
 						if(pTilemapItem->m_Version <= 2)
 							pTilemapItem->m_Front = *((const int *)(pTilemapItem) + 17);
 
-						pTiles = std::make_shared<CLayerFront>(m_pEditor, pTilemapItem->m_Width, pTilemapItem->m_Height);
+						pTiles = std::make_shared<CLayerFront>(this, pTilemapItem->m_Width, pTilemapItem->m_Height);
 						MakeFrontLayer(pTiles);
 					}
 					else if(pTilemapItem->m_Flags & TILESLAYERFLAG_SWITCH)
@@ -729,7 +729,7 @@ bool CEditorMap::Load(const char *pFileName, int StorageType, const std::functio
 						if(pTilemapItem->m_Version <= 2)
 							pTilemapItem->m_Switch = *((const int *)(pTilemapItem) + 18);
 
-						pTiles = std::make_shared<CLayerSwitch>(m_pEditor, pTilemapItem->m_Width, pTilemapItem->m_Height);
+						pTiles = std::make_shared<CLayerSwitch>(this, pTilemapItem->m_Width, pTilemapItem->m_Height);
 						MakeSwitchLayer(pTiles);
 					}
 					else if(pTilemapItem->m_Flags & TILESLAYERFLAG_TUNE)
@@ -737,13 +737,12 @@ bool CEditorMap::Load(const char *pFileName, int StorageType, const std::functio
 						if(pTilemapItem->m_Version <= 2)
 							pTilemapItem->m_Tune = *((const int *)(pTilemapItem) + 19);
 
-						pTiles = std::make_shared<CLayerTune>(m_pEditor, pTilemapItem->m_Width, pTilemapItem->m_Height);
+						pTiles = std::make_shared<CLayerTune>(this, pTilemapItem->m_Width, pTilemapItem->m_Height);
 						MakeTuneLayer(pTiles);
 					}
 					else
 					{
-						pTiles = std::make_shared<CLayerTiles>(m_pEditor, pTilemapItem->m_Width, pTilemapItem->m_Height);
-						pTiles->m_pEditor = m_pEditor;
+						pTiles = std::make_shared<CLayerTiles>(this, pTilemapItem->m_Width, pTilemapItem->m_Height);
 						pTiles->m_Color = pTilemapItem->m_Color;
 						pTiles->m_ColorEnv = pTilemapItem->m_ColorEnv;
 						pTiles->m_ColorEnvOffset = pTilemapItem->m_ColorEnvOffset;
@@ -872,7 +871,7 @@ bool CEditorMap::Load(const char *pFileName, int StorageType, const std::functio
 				{
 					const CMapItemLayerQuads *pQuadsItem = (CMapItemLayerQuads *)pLayerItem;
 
-					std::shared_ptr<CLayerQuads> pQuads = std::make_shared<CLayerQuads>(m_pEditor);
+					std::shared_ptr<CLayerQuads> pQuads = std::make_shared<CLayerQuads>(this);
 					pQuads->m_Flags = pLayerItem->m_Flags;
 					pQuads->m_Image = pQuadsItem->m_Image;
 
@@ -902,7 +901,7 @@ bool CEditorMap::Load(const char *pFileName, int StorageType, const std::functio
 					if(pSoundsItem->m_Version < 1 || pSoundsItem->m_Version > 2)
 						continue;
 
-					std::shared_ptr<CLayerSounds> pSounds = std::make_shared<CLayerSounds>(m_pEditor);
+					std::shared_ptr<CLayerSounds> pSounds = std::make_shared<CLayerSounds>(this);
 					pSounds->m_Flags = pLayerItem->m_Flags;
 					pSounds->m_Sound = pSoundsItem->m_Sound;
 
@@ -933,7 +932,7 @@ bool CEditorMap::Load(const char *pFileName, int StorageType, const std::functio
 					if(pSoundsItem->m_Version < 1 || pSoundsItem->m_Version > 2)
 						continue;
 
-					std::shared_ptr<CLayerSounds> pSounds = std::make_shared<CLayerSounds>(m_pEditor);
+					std::shared_ptr<CLayerSounds> pSounds = std::make_shared<CLayerSounds>(this);
 					pSounds->m_Flags = pLayerItem->m_Flags;
 					pSounds->m_Sound = pSoundsItem->m_Sound;
 
@@ -1048,13 +1047,14 @@ bool CEditorMap::Load(const char *pFileName, int StorageType, const std::functio
 		}
 	}
 
+	CheckIntegrity();
 	PerformSanityChecks(ErrorHandler);
 
 	ResetModifiedState();
 	return true;
 }
 
-void CEditorMap::PerformSanityChecks(const std::function<void(const char *pErrorMessage)> &ErrorHandler)
+void CEditorMap::PerformSanityChecks(const FErrorHandler &ErrorHandler)
 {
 	// Check if there are any images with a width or height that is not divisible by 16 which are
 	// used in tile layers. Reset the image for these layers, to prevent crashes with some drivers.
