@@ -31,6 +31,19 @@ typedef std::function<void(const char *pCaption, const char *pContent, int Incre
 
 constexpr int BorderRenderDistance = 201;
 
+class CClipRegion
+{
+public:
+	CClipRegion() = default;
+	CClipRegion(float X, float Y, float Width, float Height) :
+		m_X(X), m_Y(Y), m_Width(Width), m_Height(Height) {}
+
+	float m_X;
+	float m_Y;
+	float m_Width;
+	float m_Height;
+};
+
 class CRenderLayerParams
 {
 public:
@@ -44,6 +57,8 @@ public:
 	bool m_RenderTileBorder;
 	bool m_DebugRenderGroupClips;
 	bool m_DebugRenderQuadClips;
+	bool m_DebugRenderClusterClips;
+	bool m_DebugRenderTileClips;
 };
 
 class CRenderLayer : public CRenderComponent
@@ -59,6 +74,7 @@ public:
 	virtual bool IsGroup() const { return false; }
 	virtual void Unload() = 0;
 
+	bool IsVisibleInClipRegion(const std::optional<CClipRegion> &ClipRegion) const;
 	int GetGroup() const { return m_GroupId; }
 
 protected:
@@ -74,6 +90,7 @@ protected:
 	IMapImages *m_pMapImages = nullptr;
 	std::shared_ptr<CEnvelopeManager> m_pEnvelopeManager;
 	std::optional<FRenderUploadCallback> m_RenderUploadCallback;
+	std::optional<CClipRegion> m_LayerClip;
 };
 
 class CRenderLayerGroup : public CRenderLayer
@@ -220,8 +237,6 @@ public:
 
 protected:
 	IGraphics::CTextureHandle GetTexture() const override { return m_TextureHandle; }
-	void CalculateClipping();
-	bool CalculateQuadClipping(int aQuadOffsetMin[2], int aQuadOffsetMax[2], bool Grouped);
 
 	class CQuadLayerVisuals : public CRenderComponent
 	{
@@ -234,30 +249,30 @@ protected:
 		int m_BufferContainerIndex;
 		bool m_IsTextured;
 	};
-	void RenderQuadLayer(float Alpha = 1.0f);
+	void RenderQuadLayer(float Alpha, const CRenderLayerParams &Params);
 
 	std::optional<CRenderLayerQuads::CQuadLayerVisuals> m_VisualQuad;
 	CMapItemLayerQuads *m_pLayerQuads;
 
-	std::vector<SQuadRenderInfo> m_vQuadRenderInfo;
-
-	bool m_Grouped;
-	class CQuadRenderGroup
+	class CQuadCluster
 	{
 	public:
+		bool m_Grouped;
+		int m_StartIndex;
+		int m_NumQuads;
+
 		int m_PosEnv;
 		float m_PosEnvOffset;
 		int m_ColorEnv;
 		float m_ColorEnvOffset;
 
-		// quad clipping
-		bool m_Clipped;
-		float m_ClipX;
-		float m_ClipY;
-		float m_ClipWidth;
-		float m_ClipHeight;
-	} m_QuadRenderGroup;
+		std::vector<SQuadRenderInfo> m_vQuadRenderInfo;
+		std::optional<CClipRegion> m_ClipRegion;
+	};
+	void CalculateClipping(CQuadCluster &QuadCluster);
+	bool CalculateQuadClipping(const CQuadCluster &QuadCluster, float aQuadOffsetMin[2], float aQuadOffsetMax[2]) const;
 
+	std::vector<CQuadCluster> m_vQuadClusters;
 	CQuad *m_pQuads;
 
 private:
