@@ -198,7 +198,7 @@ static float SolveBezier(float x, float p0, float p1, float p2, float p3)
 		const double c = x0 / x3;
 
 		// substitute t = y - a / 3
-		const double sub = a / 3.0;
+		const double Substitute = a / 3.0;
 
 		// depressed form x^3 + px + q = 0
 		// cardano's method
@@ -211,34 +211,34 @@ static float SolveBezier(float x, float p0, float p1, float p2, float p3)
 		{
 			// only one 'real' solution
 			const double s = std::sqrt(D);
-			return std::cbrt(s - q) - std::cbrt(s + q) - sub;
+			return std::cbrt(s - q) - std::cbrt(s + q) - Substitute;
 		}
 		else if(D == 0.0)
 		{
 			// one single, one double solution or triple solution
 			const double s = std::cbrt(-q);
-			const double t = 2.0 * s - sub;
+			const double t = 2.0 * s - Substitute;
 
 			if(0.0 <= t && t <= 1.0001)
 				return t;
-			return (-s - sub);
+			return (-s - Substitute);
 		}
 		else
 		{
 			// Casus irreducibilis ... ,_,
-			const double phi = std::acos(-q / std::sqrt(-(p * p * p))) / 3.0;
+			const double Phi = std::acos(-q / std::sqrt(-(p * p * p))) / 3.0;
 			const double s = 2.0 * std::sqrt(-p);
 
-			const double t1 = s * std::cos(phi) - sub;
+			const double t1 = s * std::cos(Phi) - Substitute;
 
 			if(0.0 <= t1 && t1 <= 1.0001)
 				return t1;
 
-			const double t2 = -s * std::cos(phi + pi / 3.0) - sub;
+			const double t2 = -s * std::cos(Phi + pi / 3.0) - Substitute;
 
 			if(0.0 <= t2 && t2 <= 1.0001)
 				return t2;
-			return -s * std::cos(phi - pi / 3.0) - sub;
+			return -s * std::cos(Phi - pi / 3.0) - Substitute;
 		}
 	}
 }
