@@ -29,7 +29,7 @@ CDragger::CDragger(CGameWorld *pGameWorld, vec2 Pos, float Strength, bool Ignore
 	{
 		TargetId = -1;
 	}
-	mem_zero(m_apDraggerBeam, sizeof(m_apDraggerBeam));
+	std::fill(std::begin(m_apDraggerBeam), std::end(m_apDraggerBeam), nullptr);
 	GameWorld()->InsertEntity(this);
 }
 
@@ -58,7 +58,7 @@ void CDragger::LookForPlayersToDrag()
 {
 	// Create a list of players who are in the range of the dragger
 	CEntity *apPlayersInRange[MAX_CLIENTS];
-	mem_zero(apPlayersInRange, sizeof(apPlayersInRange));
+	std::fill(std::begin(apPlayersInRange), std::end(apPlayersInRange), nullptr);
 
 	int NumPlayersInRange = GameServer()->m_World.FindEntities(m_Pos,
 		g_Config.m_SvDraggerRange - CCharacterCore::PhysicalSize(),
@@ -69,13 +69,10 @@ void CDragger::LookForPlayersToDrag()
 	bool aCanStillBeTeamTarget[MAX_CLIENTS];
 	bool aIsTarget[MAX_CLIENTS];
 	int aMinDistInTeam[MAX_CLIENTS];
-	mem_zero(aCanStillBeTeamTarget, sizeof(aCanStillBeTeamTarget));
-	mem_zero(aMinDistInTeam, sizeof(aMinDistInTeam));
-	mem_zero(aIsTarget, sizeof(aIsTarget));
-	for(int &TargetId : aClosestTargetIdInTeam)
-	{
-		TargetId = -1;
-	}
+	std::fill(std::begin(aCanStillBeTeamTarget), std::end(aCanStillBeTeamTarget), false);
+	std::fill(std::begin(aMinDistInTeam), std::end(aMinDistInTeam), 0);
+	std::fill(std::begin(aIsTarget), std::end(aIsTarget), false);
+	std::fill(std::begin(aClosestTargetIdInTeam), std::end(aClosestTargetIdInTeam), -1);
 
 	for(int i = 0; i < NumPlayersInRange; i++)
 	{
@@ -242,6 +239,6 @@ void CDragger::SwapClients(int Client1, int Client2)
 	std::swap(m_apDraggerBeam[Client1], m_apDraggerBeam[Client2]);
 	for(int &TargetId : m_aTargetIdInTeam)
 	{
-		TargetId = TargetId == Client1 ? Client2 : TargetId == Client2 ? Client1 : TargetId;
+		TargetId = TargetId == Client1 ? Client2 : (TargetId == Client2 ? Client1 : TargetId);
 	}
 }
