@@ -128,5 +128,5 @@ void CPlasma::Snap(int SnappingClient)
 
 void CPlasma::SwapClients(int Client1, int Client2)
 {
-	m_ForClientId = m_ForClientId == Client1 ? Client2 : m_ForClientId == Client2 ? Client1 : m_ForClientId;
+	m_ForClientId = m_ForClientId == Client1 ? Client2 : (m_ForClientId == Client2 ? Client1 : m_ForClientId);
 }
