@@ -10,6 +10,8 @@
 
 #include <engine/shared/config.h>
 
+#include <game/collision.h>
+
 #include <algorithm>
 #include <utility>
 
@@ -43,6 +45,12 @@ void CGameWorld::SetGameServer(CGameContext *pGameServer)
 	m_pServer = m_pGameServer->Server();
 }
 
+void CGameWorld::Init(CCollision *pCollision, CTuningParams *pTuningList)
+{
+	m_Core.InitSwitchers(pCollision->m_HighestSwitchNumber);
+	m_pTuningList = pTuningList;
+}
+
 CEntity *CGameWorld::FindFirst(int Type)
 {
 	return Type < 0 || Type >= NUM_ENTTYPES ? nullptr : m_apFirstEntityTypes[Type];
@@ -383,8 +391,3 @@ void CGameWorld::ReleaseHooked(int ClientId)
 		}
 	}
 }
-
-CTuningParams *CGameWorld::Tuning()
-{
-	return &m_Core.m_aTuning[0];
-}
