@@ -296,7 +296,6 @@ void CScore::SaveTeam(int ClientId, const char *pCode, const char *pServer)
 		return;
 	auto *pController = GameServer()->m_pController;
 	int Team = pController->Teams().m_Core.Team(ClientId);
-	char aBuf[512];
 	if(pController->Teams().GetSaving(Team))
 	{
 		GameServer()->SendChatTarget(ClientId, "Team save already in progress");
@@ -308,7 +307,7 @@ void CScore::SaveTeam(int ClientId, const char *pCode, const char *pServer)
 		return;
 	}
 
-	auto SaveResult = std::make_shared<CScoreSaveResult>(ClientId);
+	auto SaveResult = std::make_shared<CScoreSaveResult>(ClientId, Server()->ClientName(ClientId), pServer);
 	SaveResult->m_SaveId = RandomUuid();
 	ESaveResult Result = SaveResult->m_SavedTeam.Save(GameServer(), Team);
 	if(CSaveTeam::HandleSaveError(Result, ClientId, GameServer()))
@@ -323,23 +322,18 @@ void CScore::SaveTeam(int ClientId, const char *pCode, const char *pServer)
 	Tmp->m_aGeneratedCode[0] = '\0';
 	GeneratePassphrase(Tmp->m_aGeneratedCode, sizeof(Tmp->m_aGeneratedCode));
 
-	if(Tmp->m_aCode[0] == '\0')
-	{
-		str_format(aBuf,
-			sizeof(aBuf),
-			"Team save in progress. You'll be able to load with '/load %s'",
-			Tmp->m_aGeneratedCode);
-	}
-	else
-	{
-		str_format(aBuf,
-			sizeof(aBuf),
-			"Team save in progress. You'll be able to load with '/load %s' if save is successful or with '/load %s' if it fails",
-			Tmp->m_aCode,
-			Tmp->m_aGeneratedCode);
-	}
 	pController->Teams().KillCharacterOrTeam(ClientId, Team);
-	GameServer()->SendChatTeam(Team, aBuf);
+
+	GameServer()->SendSaveCode(
+		Team,
+		SaveResult->m_SavedTeam.GetMembersCount(),
+		SAVESTATE_PENDING,
+		"",
+		SaveResult->m_aRequestingPlayer,
+		Tmp->m_aServer,
+		Tmp->m_aGeneratedCode,
+		Tmp->m_aCode);
+
 	m_pPool->ExecuteWrite(CScoreWorker::SaveTeam, std::move(Tmp), "save team");
 }
 
@@ -354,7 +348,7 @@ void CScore::LoadTeam(const char *pCode, int ClientId)
 		GameServer()->SendChatTarget(ClientId, "Team load already in progress");
 		return;
 	}
-	if(Team < TEAM_FLOCK || Team >= MAX_CLIENTS || (g_Config.m_SvTeam != SV_TEAM_FORCED_SOLO && Team == TEAM_FLOCK))
+	if(!pController->Teams().IsValidTeamNumber(Team) || (g_Config.m_SvTeam != SV_TEAM_FORCED_SOLO && Team == TEAM_FLOCK))
 	{
 		GameServer()->SendChatTarget(ClientId, "You have to be in a team (from 1-63)");
 		return;
@@ -374,7 +368,7 @@ void CScore::LoadTeam(const char *pCode, int ClientId)
 		GameServer()->SendChatTarget(ClientId, "Team can't be loaded while practice is enabled");
 		return;
 	}
-	auto SaveResult = std::make_shared<CScoreSaveResult>(ClientId);
+	auto SaveResult = std::make_shared<CScoreSaveResult>(ClientId, Server()->ClientName(ClientId), g_Config.m_SvSqlServerName);
 	SaveResult->m_Status = CScoreSaveResult::LOAD_FAILED;
 	pController->Teams().SetSaving(Team, SaveResult);
 	auto Tmp = std::make_unique<CSqlTeamLoadRequest>(SaveResult);
