@@ -40,14 +40,14 @@ class CGameTeams
 	// the message from playing for a long time in an unfinishable team.
 	int m_aTeamUnfinishableKillTick[NUM_DDRACE_TEAMS];
 
-	class CGameContext *m_pGameContext;
+	CGameContext *m_pGameContext;
 
 	/**
-	* Kill the whole team.
-	* @param Team The team id to kill
-	* @param NewStrongId The player with that id will get strong hook on everyone else, -1 will set the normal spawning order
-	* @param ExceptId The player that should not get killed
-	*/
+	 * Kill the whole team.
+	 * @param Team The team id to kill
+	 * @param NewStrongId The player with that id will get strong hook on everyone else, -1 will set the normal spawning order
+	 * @param ExceptId The player that should not get killed
+	 */
 	void KillTeam(int Team, int NewStrongId, int ExceptId = -1);
 	bool TeamFinished(int Team);
 	void OnTeamFinish(int Team, CPlayer **Players, unsigned int Size, int TimeTicks, const char *pTimestamp);
@@ -60,8 +60,10 @@ public:
 
 	// helper methods
 	CCharacter *Character(int ClientId);
+	const CCharacter *Character(int ClientId) const;
 	CPlayer *GetPlayer(int ClientId);
-	class CGameContext *GameServer();
+	CGameContext *GameServer();
+	const CGameContext *GameServer() const;
 	class IServer *Server();
 
 	void OnCharacterStart(int ClientId);
@@ -70,8 +72,12 @@ public:
 	void OnCharacterDeath(int ClientId, int Weapon);
 	void Tick();
 
-	// returns nullptr if successful, error string if failed
-	const char *SetCharacterTeam(int ClientId, int Team);
+	// sets pError to an empty string on success (true)
+	// and sets pError if it returns false
+	bool CanJoinTeam(int ClientId, int Team, char *pError, int ErrorSize) const;
+
+	// returns true if successful. Writes error into pError on failure
+	bool SetCharacterTeam(int ClientId, int Team, char *pError, int ErrorSize);
 	void CheckTeamFinished(int Team);
 
 	void ChangeTeamState(int Team, ETeamState State);
@@ -119,6 +125,7 @@ public:
 	bool GetSaving(int TeamId) const;
 	void SetPractice(int Team, bool Enabled);
 	bool IsPractice(int Team);
+	bool IsValidTeamNumber(int Team) const;
 };
 
 #endif
